class Math(object):
 """ Provides constants and static methods for trigonometric,logarithmic,and other common mathematical functions. """
 @staticmethod
 def Abs(value):
  """
  Abs(value: Single) -> Single

  

   Returns the absolute value of a single-precision floating-point number.

  

   value: A number that is greater than or equal to System.Single.MinValue,but less than or equal to 

    System.Single.MaxValue.

  

    Abs(value: float) -> float

  

   Returns the absolute value of a double-precision floating-point number.

  

   value: A number that is greater than or equal to System.Double.MinValue,but less than or equal to 

    System.Double.MaxValue.

  

    Abs(value: Decimal) -> Decimal

  

   Returns the absolute value of a System.Decimal number.

  

   value: A number that is greater than or equal to System.Decimal.MinValue,but less than or equal to 

    System.Decimal.MaxValue.

  

    Abs(value: Int64) -> Int64

  

   Returns the absolute value of a 64-bit signed integer.

  

   value: A number that is greater than System.Int64.MinValue,but less than or equal to 

    System.Int64.MaxValue.

  

    Abs(value: SByte) -> SByte

  

   Returns the absolute value of an 8-bit signed integer.

  

   value: A number that is greater than System.SByte.MinValue,but less than or equal to 

    System.SByte.MaxValue.

  

    Abs(value: Int16) -> Int16

  

   Returns the absolute value of a 16-bit signed integer.

  

   value: A number that is greater than System.Int16.MinValue,but less than or equal to 

    System.Int16.MaxValue.

  

    Abs(value: int) -> int

  

   Returns the absolute value of a 32-bit signed integer.

  

   value: A number that is greater than System.Int32.MinValue,but less than or equal to 

    System.Int32.MaxValue.

  

    """
  pass
 @staticmethod
 def Acos(d):
  """
  Acos(d: float) -> float

  

   Returns the angle whose cosine is the specified number.

  

   d: A number representing a cosine,where d must be greater than or equal to -1,but less than or 

    equal to 1.

  

      equals System.Double.NaN.
  """
  pass
 @staticmethod
 def Asin(d):
  """
  Asin(d: float) -> float

  

   Returns the angle whose sine is the specified number.

  

   d: A number representing a sine,where d must be greater than or equal to -1,but less than or 

    equal to 1.

  

      1 or d equals System.Double.NaN.
  """
  pass
 @staticmethod
 def Atan(d):
  """
  Atan(d: float) -> float

  

   Returns the angle whose tangent is the specified number.

  

   d: A number representing a tangent.

          System.Double.PositiveInfinity.
  """
  pass
 @staticmethod
 def Atan2(y,x):
  """
  Atan2(y: float,x: float) -> float

  

   Returns the angle whose tangent is the quotient of two specified numbers.

  

   y: The y coordinate of a point.

   x: The x coordinate of a point.

                either System.Double.PositiveInfinity or System.Double.NegativeInfinity,the method returns 

    System.Double.NaN.
  """
  pass
 @staticmethod
 def BigMul(a,b):
  """
  BigMul(a: int,b: int) -> Int64

  

   Produces the full product of two 32-bit numbers.

  

   a: The first number to multiply.

   b: The second number to multiply.

   Returns: The number containing the product of the specified numbers.
  """
  pass
 @staticmethod
 def Ceiling(*__args):
  """
  Ceiling(a: float) -> float

  

   Returns the smallest integral value that is greater than or equal to the specified 

    double-precision floating-point number.

  

  

   a: A double-precision floating-point number.

   Returns: The smallest integral value that is greater than or equal to a. If a is equal to 

    System.Double.NaN,System.Double.NegativeInfinity,or System.Double.PositiveInfinity,that value 

    is returned. Note that this method returns a System.Double instead of an integral type.

  

  Ceiling(d: Decimal) -> Decimal

  

   Returns the smallest integral value that is greater than or equal to the specified decimal 

    number.

  

  

   d: A decimal number.

   Returns: The smallest integral value that is greater than or equal to d. Note that this method returns a 

    System.Decimal instead of an integral type.
  """
  pass
 @staticmethod
 def Cos(d):
  """
  Cos(d: float) -> float

  

   Returns the cosine of the specified angle.

  

   d: An angle,measured in radians.

   Returns: The cosine of d. If d is equal to System.Double.NaN,System.Double.NegativeInfinity,or 

    System.Double.PositiveInfinity,this method returns System.Double.NaN.
  """
  pass
 @staticmethod
 def Cosh(value):
  """
  Cosh(value: float) -> float

  

   Returns the hyperbolic cosine of the specified angle.

  

   value: An angle,measured in radians.

   Returns: The hyperbolic cosine of value. If value is equal to System.Double.NegativeInfinity or 

    System.Double.PositiveInfinity,System.Double.PositiveInfinity is returned. If value is equal to 

    System.Double.NaN,System.Double.NaN is returned.
  """
  pass
 @staticmethod
 def DivRem(a,b,result):
  """
  DivRem(a: Int64,b: Int64) -> (Int64,Int64)

  

   Calculates the quotient of two 64-bit signed integers and also returns the remainder in an 

    output parameter.

  

  

   a: The dividend.

   b: The divisor.

   Returns: The quotient of the specified numbers.

  DivRem(a: int,b: int) -> (int,int)

  

   Calculates the quotient of two 32-bit signed integers and also returns the remainder in an 

    output parameter.

  

  

   a: The dividend.

   b: The divisor.

   Returns: The quotient of the specified numbers.
  """
  pass
 @staticmethod
 def Exp(d):
  """
  Exp(d: float) -> float

  

   Returns e raised to the specified power.

  

   d: A number specifying a power.

   Returns: The number e raised to the power d. If d equals System.Double.NaN or 

    System.Double.PositiveInfinity,that value is returned. If d equals 

    System.Double.NegativeInfinity,0 is returned.
  """
  pass
 @staticmethod
 def Floor(d):
  """
  Floor(d: float) -> float

  

   Returns the largest integer less than or equal to the specified double-precision floating-point 

    number.

  

  

   d: A double-precision floating-point number.

   Returns: The largest integer less than or equal to d. If d is equal to System.Double.NaN,

    System.Double.NegativeInfinity,or System.Double.PositiveInfinity,that value is returned.

  

  Floor(d: Decimal) -> Decimal

  

   Returns the largest integer less than or equal to the specified decimal number.

  

   d: A decimal number.

   Returns: The largest integer less than or equal to d.
  """
  pass
 @staticmethod
 def IEEERemainder(x,y):
  """
  IEEERemainder(x: float,y: float) -> float

  

   Returns the remainder resulting from the division of a specified number by another specified 

    number.

  

  

   x: A dividend.

   y: A divisor.

   Returns: A number equal to x - (y Q),where Q is the quotient of x / y rounded to the nearest integer (if 

    x / y falls halfway between two integers,the even integer is returned).If x - (y Q) is zero,

    the value +0 is returned if x is positive,or -0 if x is negative.If y=0,System.Double.NaN is 

    returned.
  """
  pass
 @staticmethod
 def Log(*__args):
  """
  Log(a: float,newBase: float) -> float

  

   Returns the logarithm of a specified number in a specified base.

  

   a: A number whose logarithm is to be found.

   newBase: The base of the logarithm.

   Returns: One of the values in the following table. (+Infinity denotes System.Double.PositiveInfinity,

    -Infinity denotes System.Double.NegativeInfinity,and NaN denotes 

    System.Double.NaN.)anewBaseReturn valuea> 0(0 <newBase< 1) -or-(newBase> 1)lognewBase(a)a< 0(any 

    value)NaN(any value)newBase< 0NaNa != 1newBase=0NaNa != 1newBase=+InfinityNaNa=NaN(any 

    value)NaN(any value)newBase=NaNNaN(any value)newBase=1NaNa=00 <newBase< 1 +Infinitya=

    0newBase> 1-Infinitya= +Infinity0 <newBase< 1-Infinitya= +InfinitynewBase> 1+Infinitya=

    1newBase=00a=1newBase=+Infinity0

  

  Log(d: float) -> float

  

   Returns the natural (base e) logarithm of a specified number.

  

   d: A number whose logarithm is to be found.

   Returns: One of the values in the following table. d parameterReturn value Positive The natural logarithm 

    of d; that is,ln d,or log edZero System.Double.NegativeInfinityNegative System.Double.NaNEqual 

    to System.Double.NaNSystem.Double.NaNEqual to 

    System.Double.PositiveInfinitySystem.Double.PositiveInfinity
  """
  pass
 @staticmethod
 def Log10(d):
  """
  Log10(d: float) -> float

  

   Returns the base 10 logarithm of a specified number.

  

   d: A number whose logarithm is to be found.

   Returns: One of the values in the following table. d parameter Return value Positive The base 10 log of 

    d; that is,log 10d. Zero System.Double.NegativeInfinityNegative System.Double.NaNEqual to 

    System.Double.NaNSystem.Double.NaNEqual to 

    System.Double.PositiveInfinitySystem.Double.PositiveInfinity
  """
  pass
 @staticmethod
 def Max(val1,val2):
  """
  Max(val1: UInt64,val2: UInt64) -> UInt64

  

   Returns the larger of two 64-bit unsigned integers.

  

   val1: The first of two 64-bit unsigned integers to compare.

   val2: The second of two 64-bit unsigned integers to compare.

   Returns: Parameter val1 or val2,whichever is larger.

  Max(val1: Int64,val2: Int64) -> Int64

  

   Returns the larger of two 64-bit signed integers.

  

   val1: The first of two 64-bit signed integers to compare.

   val2: The second of two 64-bit signed integers to compare.

   Returns: Parameter val1 or val2,whichever is larger.

  Max(val1: Single,val2: Single) -> Single

  

   Returns the larger of two single-precision floating-point numbers.

  

   val1: The first of two single-precision floating-point numbers to compare.

   val2: The second of two single-precision floating-point numbers to compare.

   Returns: Parameter val1 or val2,whichever is larger. If val1,or val2,or both val1 and val2 are equal 

    to System.Single.NaN,System.Single.NaN is returned.

  

  Max(val1: Decimal,val2: Decimal) -> Decimal

  

   Returns the larger of two decimal numbers.

  

   val1: The first of two decimal numbers to compare.

   val2: The second of two decimal numbers to compare.

   Returns: Parameter val1 or val2,whichever is larger.

  Max(val1: float,val2: float) -> float

  

   Returns the larger of two double-precision floating-point numbers.

  

   val1: The first of two double-precision floating-point numbers to compare.

   val2: The second of two double-precision floating-point numbers to compare.

   Returns: Parameter val1 or val2,whichever is larger. If val1,val2,or both val1 and val2 are equal to 

    System.Double.NaN,System.Double.NaN is returned.

  

  Max(val1: UInt32,val2: UInt32) -> UInt32

  

   Returns the larger of two 32-bit unsigned integers.

  

   val1: The first of two 32-bit unsigned integers to compare.

   val2: The second of two 32-bit unsigned integers to compare.

   Returns: Parameter val1 or val2,whichever is larger.

  Max(val1: Byte,val2: Byte) -> Byte

  

   Returns the larger of two 8-bit unsigned integers.

  

   val1: The first of two 8-bit unsigned integers to compare.

   val2: The second of two 8-bit unsigned integers to compare.

   Returns: Parameter val1 or val2,whichever is larger.

  Max(val1: SByte,val2: SByte) -> SByte

  

   Returns the larger of two 8-bit signed integers.

  

   val1: The first of two 8-bit signed integers to compare.

   val2: The second of two 8-bit signed integers to compare.

   Returns: Parameter val1 or val2,whichever is larger.

  Max(val1: Int16,val2: Int16) -> Int16

  

   Returns the larger of two 16-bit signed integers.

  

   val1: The first of two 16-bit signed integers to compare.

   val2: The second of two 16-bit signed integers to compare.

   Returns: Parameter val1 or val2,whichever is larger.

  Max(val1: int,val2: int) -> int

  

   Returns the larger of two 32-bit signed integers.

  

   val1: The first of two 32-bit signed integers to compare.

   val2: The second of two 32-bit signed integers to compare.

   Returns: Parameter val1 or val2,whichever is larger.

  Max(val1: UInt16,val2: UInt16) -> UInt16

  

   Returns the larger of two 16-bit unsigned integers.

  

   val1: The first of two 16-bit unsigned integers to compare.

   val2: The second of two 16-bit unsigned integers to compare.

   Returns: Parameter val1 or val2,whichever is larger.
  """
  pass
 @staticmethod
 def Min(val1,val2):
  """
  Min(val1: UInt64,val2: UInt64) -> UInt64

  

   Returns the smaller of two 64-bit unsigned integers.

  

   val1: The first of two 64-bit unsigned integers to compare.

   val2: The second of two 64-bit unsigned integers to compare.

   Returns: Parameter val1 or val2,whichever is smaller.

  Min(val1: Int64,val2: Int64) -> Int64

  

   Returns the smaller of two 64-bit signed integers.

  

   val1: The first of two 64-bit signed integers to compare.

   val2: The second of two 64-bit signed integers to compare.

   Returns: Parameter val1 or val2,whichever is smaller.

  Min(val1: Single,val2: Single) -> Single

  

   Returns the smaller of two single-precision floating-point numbers.

  

   val1: The first of two single-precision floating-point numbers to compare.

   val2: The second of two single-precision floating-point numbers to compare.

   Returns: Parameter val1 or val2,whichever is smaller. If val1,val2,or both val1 and val2 are equal to 

    System.Single.NaN,System.Single.NaN is returned.

  

  Min(val1: Decimal,val2: Decimal) -> Decimal

  

   Returns the smaller of two decimal numbers.

  

   val1: The first of two decimal numbers to compare.

   val2: The second of two decimal numbers to compare.

   Returns: Parameter val1 or val2,whichever is smaller.

  Min(val1: float,val2: float) -> float

  

   Returns the smaller of two double-precision floating-point numbers.

  

   val1: The first of two double-precision floating-point numbers to compare.

   val2: The second of two double-precision floating-point numbers to compare.

   Returns: Parameter val1 or val2,whichever is smaller. If val1,val2,or both val1 and val2 are equal to 

    System.Double.NaN,System.Double.NaN is returned.

  

  Min(val1: UInt32,val2: UInt32) -> UInt32

  

   Returns the smaller of two 32-bit unsigned integers.

  

   val1: The first of two 32-bit unsigned integers to compare.

   val2: The second of two 32-bit unsigned integers to compare.

   Returns: Parameter val1 or val2,whichever is smaller.

  Min(val1: Byte,val2: Byte) -> Byte

  

   Returns the smaller of two 8-bit unsigned integers.

  

   val1: The first of two 8-bit unsigned integers to compare.

   val2: The second of two 8-bit unsigned integers to compare.

   Returns: Parameter val1 or val2,whichever is smaller.

  Min(val1: SByte,val2: SByte) -> SByte

  

   Returns the smaller of two 8-bit signed integers.

  

   val1: The first of two 8-bit signed integers to compare.

   val2: The second of two 8-bit signed integers to compare.

   Returns: Parameter val1 or val2,whichever is smaller.

  Min(val1: Int16,val2: Int16) -> Int16

  

   Returns the smaller of two 16-bit signed integers.

  

   val1: The first of two 16-bit signed integers to compare.

   val2: The second of two 16-bit signed integers to compare.

   Returns: Parameter val1 or val2,whichever is smaller.

  Min(val1: int,val2: int) -> int

  

   Returns the smaller of two 32-bit signed integers.

  

   val1: The first of two 32-bit signed integers to compare.

   val2: The second of two 32-bit signed integers to compare.

   Returns: Parameter val1 or val2,whichever is smaller.

  Min(val1: UInt16,val2: UInt16) -> UInt16

  

   Returns the smaller of two 16-bit unsigned integers.

  

   val1: The first of two 16-bit unsigned integers to compare.

   val2: The second of two 16-bit unsigned integers to compare.

   Returns: Parameter val1 or val2,whichever is smaller.
  """
  pass
 @staticmethod
 def Pow(x,y):
  """
  Pow(x: float,y: float) -> float

  

   Returns a specified number raised to the specified power.

  

   x: A double-precision floating-point number to be raised to a power.

   y: A double-precision floating-point number that specifies a power.

   Returns: The number x raised to the power y.
  """
  pass
 @staticmethod
 def Round(*__args):
  """
  Round(d: Decimal,decimals: int) -> Decimal

  

   Rounds a decimal value to a specified number of fractional digits.

  

   d: A decimal number to be rounded.

   decimals: The number of decimal places in the return value.

   Returns: The number nearest to d that contains a number of fractional digits equal to decimals.

  Round(d: Decimal) -> Decimal

  

   Rounds a decimal value to the nearest integral value.

  

   d: A decimal number to be rounded.

   Returns: The integer nearest parameter d. If the fractional component of d is halfway between two 

    integers,one of which is even and the other odd,the even number is returned. Note that this 

    method returns a System.Decimal instead of an integral type.

  

  Round(d: Decimal,decimals: int,mode: MidpointRounding) -> Decimal

  

   Rounds a decimal value to a specified number of fractional digits. A parameter specifies how to 

    round the value if it is midway between two other numbers.

  

  

   d: A decimal number to be rounded.

   decimals: The number of decimal places in the return value.

   mode: Specification for how to round d if it is midway between two other numbers.

   Returns: The number nearest to d that contains a number of fractional digits equal to decimals. If d has 

    fewer fractional digits than decimals,d is returned unchanged.

  

  Round(d: Decimal,mode: MidpointRounding) -> Decimal

  

   Rounds a decimal value to the nearest integer. A parameter specifies how to round the value if 

    it is midway between two other numbers.

  

  

   d: A decimal number to be rounded.

   mode: Specification for how to round d if it is midway between two other numbers.

   Returns: The integer nearest d. If d is halfway between two numbers,one of which is even and the other 

    odd,then mode determines which of the two is returned.

  

  Round(value: float,digits: int) -> float

  

   Rounds a double-precision floating-point value to a specified number of fractional digits.

  

   value: A double-precision floating-point number to be rounded.

   digits: The number of fractional digits in the return value.

   Returns: The number nearest to value that contains a number of fractional digits equal to digits.

  Round(a: float) -> float

  

   Rounds a double-precision floating-point value to the nearest integral value.

  

   a: A double-precision floating-point number to be rounded.

   Returns: The integer nearest a. If the fractional component of a is halfway between two integers,one of 

    which is even and the other odd,then the even number is returned. Note that this method returns 

    a System.Double instead of an integral type.

  

  Round(value: float,digits: int,mode: MidpointRounding) -> float

  

   Rounds a double-precision floating-point value to the specified number of fractional digits. A 

    parameter specifies how to round the value if it is midway between two other numbers.

  

  

   value: A double-precision floating-point number to be rounded.

   digits: The number of fractional digits in the return value.

   mode: Specification for how to round value if it is midway between two other numbers.

   Returns: The number nearest to value that has a number of fractional digits equal to digits. If value has 

    fewer fractional digits than digits,value is returned unchanged.

  

  Round(value: float,mode: MidpointRounding) -> float

  

   Rounds a double-precision floating-point value to the nearest integer. A parameter specifies how 

    to round the value if it is midway between two other numbers.

  

  

   value: A double-precision floating-point number to be rounded.

   mode: Specification for how to round value if it is midway between two other numbers.

   Returns: The integer nearest value. If value is halfway between two integers,one of which is even and 

    the other odd,then mode determines which of the two is returned.
  """
  pass
 @staticmethod
 def Sign(value):
  """
  Sign(value: Single) -> int

  

   Returns a value indicating the sign of a single-precision floating-point number.

  

   value: A signed number.

   Returns: A number that indicates the sign of value,as shown in the following table.Return value Meaning 

    -1 value is less than zero. 0 value is equal to zero. 1 value is greater than zero.

  

  Sign(value: float) -> int

  

   Returns a value indicating the sign of a double-precision floating-point number.

  

   value: A signed number.

   Returns: A number that indicates the sign of value,as shown in the following table.Return value Meaning 

    -1 value is less than zero. 0 value is equal to zero. 1 value is greater than zero.

  

  Sign(value: Decimal) -> int

  

   Returns a value indicating the sign of a decimal number.

  

   value: A signed decimal number.

   Returns: A number that indicates the sign of value,as shown in the following table.Return value Meaning 

    -1 value is less than zero. 0 value is equal to zero. 1 value is greater than zero.

  

  Sign(value: Int64) -> int

  

   Returns a value indicating the sign of a 64-bit signed integer.

  

   value: A signed number.

   Returns: A number that indicates the sign of value,as shown in the following table.Return value Meaning 

    -1 value is less than zero. 0 value is equal to zero. 1 value is greater than zero.

  

  Sign(value: SByte) -> int

  

   Returns a value indicating the sign of an 8-bit signed integer.

  

   value: A signed number.

   Returns: A number that indicates the sign of value,as shown in the following table.Return value Meaning 

    -1 value is less than zero. 0 value is equal to zero. 1 value is greater than zero.

  

  Sign(value: Int16) -> int

  

   Returns a value indicating the sign of a 16-bit signed integer.

  

   value: A signed number.

   Returns: A number that indicates the sign of value,as shown in the following table.Return value Meaning 

    -1 value is less than zero. 0 value is equal to zero. 1 value is greater than zero.

  

  Sign(value: int) -> int

  

   Returns a value indicating the sign of a 32-bit signed integer.

  

   value: A signed number.

   Returns: A number that indicates the sign of value,as shown in the following table.Return value Meaning 

    -1 value is less than zero. 0 value is equal to zero. 1 value is greater than zero.
  """
  pass
 @staticmethod
 def Sin(a):
  """
  Sin(a: float) -> float

  

   Returns the sine of the specified angle.

  

   a: An angle,measured in radians.

   Returns: The sine of a. If a is equal to System.Double.NaN,System.Double.NegativeInfinity,or 

    System.Double.PositiveInfinity,this method returns System.Double.NaN.
  """
  pass
 @staticmethod
 def Sinh(value):
  """
  Sinh(value: float) -> float

  

   Returns the hyperbolic sine of the specified angle.

  

   value: An angle,measured in radians.

   Returns: The hyperbolic sine of value. If value is equal to System.Double.NegativeInfinity,

    System.Double.PositiveInfinity,or System.Double.NaN,this method returns a System.Double equal 

    to value.
  """
  pass
 @staticmethod
 def Sqrt(d):
  """
  Sqrt(d: float) -> float

  

   Returns the square root of a specified number.

  

   d: A number.

   Returns: One of the values in the following table. d parameter Return value Zero,or positive The 

    positive square root of d. Negative System.Double.NaNEquals 

    System.Double.NaNSystem.Double.NaNEquals 

    System.Double.PositiveInfinitySystem.Double.PositiveInfinity
  """
  pass
 @staticmethod
 def Tan(a):
  """
  Tan(a: float) -> float

  

   Returns the tangent of the specified angle.

  

   a: An angle,measured in radians.

   Returns: The tangent of a. If a is equal to System.Double.NaN,System.Double.NegativeInfinity,or 

    System.Double.PositiveInfinity,this method returns System.Double.NaN.
  """
  pass
 @staticmethod
 def Tanh(value):
  """
  Tanh(value: float) -> float

  

   Returns the hyperbolic tangent of the specified angle.

  

   value: An angle,measured in radians.

   Returns: The hyperbolic tangent of value. If value is equal to System.Double.NegativeInfinity,this 

    method returns -1. If value is equal to System.Double.PositiveInfinity,this method returns 1. 

    If value is equal to System.Double.NaN,this method returns System.Double.NaN.
  """
  pass
 @staticmethod
 def Truncate(d):
  """
  Truncate(d: float) -> float

  

   Calculates the integral part of a specified double-precision floating-point number.

  

   d: A number to truncate.

   Returns: The integral part of d; that is,the number that remains after any fractional digits have been 

    discarded,or one of the values listed in the following table. dReturn 

    valueSystem.Double.NaNSystem.Double.NaNSystem.Double.NegativeInfinitySystem.Double.NegativeInfini

    tySystem.Double.PositiveInfinitySystem.Double.PositiveInfinity

  

  Truncate(d: Decimal) -> Decimal

  

   Calculates the integral part of a specified decimal number.

  

   d: A number to truncate.

   Returns: The integral part of d; that is,the number that remains after any fractional digits have been 

    discarded.
  """
  pass
 E=2.7182818284590451
 PI=3.1415926535897931
 __all__=[
  'Abs',
  'Acos',
  'Asin',
  'Atan',
  'Atan2',
  'BigMul',
  'Ceiling',
  'Cos',
  'Cosh',
  'DivRem',
  'E',
  'Exp',
  'Floor',
  'IEEERemainder',
  'Log',
  'Log10',
  'Max',
  'Min',
  'PI',
  'Pow',
  'Round',
  'Sign',
  'Sin',
  'Sinh',
  'Sqrt',
  'Tan',
  'Tanh',
  'Truncate',
 ]




class DrawToolTipEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.ToolTip.Draw event.

 

 DrawToolTipEventArgs(graphics: Graphics,associatedWindow: IWin32Window,associatedControl: Control,bounds: Rectangle,toolTipText: str,backColor: Color,foreColor: Color,font: Font)
 """
 def DrawBackground(self):
  """
  DrawBackground(self: DrawToolTipEventArgs)

   Draws the background of the System.Windows.Forms.ToolTip using the system background color.
  """
  pass
 def DrawBorder(self):
  """
  DrawBorder(self: DrawToolTipEventArgs)

   Draws the border of the System.Windows.Forms.ToolTip using the system border color.
  """
  pass
 def DrawText(self,flags=None):
  """
  DrawText(self: DrawToolTipEventArgs,flags: TextFormatFlags)

   Draws the text of the System.Windows.Forms.ToolTip using the system text color and font,and the 

    specified text layout.

  

  

   flags: A System.Windows.Forms.TextFormatFlags containing a bitwise combination of values that specifies 

    the display and layout for the System.Windows.Forms.DrawToolTipEventArgs.ToolTipText.

  

  DrawText(self: DrawToolTipEventArgs)

   Draws the text of the System.Windows.Forms.ToolTip using the system text color and font.
  """
  pass
 @staticmethod
 def __new__(self,graphics,associatedWindow,associatedControl,bounds,toolTipText,backColor,foreColor,font):
  """ __new__(cls: type,graphics: Graphics,associatedWindow: IWin32Window,associatedControl: Control,bounds: Rectangle,toolTipText: str,backColor: Color,foreColor: Color,font: Font) """
  pass
 AssociatedControl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the control for which the System.Windows.Forms.ToolTip is being drawn.



Get: AssociatedControl(self: DrawToolTipEventArgs) -> Control



"""

 AssociatedWindow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the window to which this System.Windows.Forms.ToolTip is bound.



Get: AssociatedWindow(self: DrawToolTipEventArgs) -> IWin32Window



"""

 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the size and location of the System.Windows.Forms.ToolTip to draw.



Get: Bounds(self: DrawToolTipEventArgs) -> Rectangle



"""

 Font=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the font used to draw the System.Windows.Forms.ToolTip.



Get: Font(self: DrawToolTipEventArgs) -> Font



"""

 Graphics=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the graphics surface used to draw the System.Windows.Forms.ToolTip.



Get: Graphics(self: DrawToolTipEventArgs) -> Graphics



"""

 ToolTipText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the text for the System.Windows.Forms.ToolTip that is being drawn.



Get: ToolTipText(self: DrawToolTipEventArgs) -> str



"""





class DebuggerDisplayAttribute(Attribute,_Attribute):
 """
 Determines how a class or field is displayed in the debugger variable windows.

 

 DebuggerDisplayAttribute(value: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,value):
  """ __new__(cls: type,value: str) """
  pass
 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name to display in the debugger variable windows.



Get: Name(self: DebuggerDisplayAttribute) -> str



Set: Name(self: DebuggerDisplayAttribute)=value

"""

 Target=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the type of the attribute's target.



Get: Target(self: DebuggerDisplayAttribute) -> Type



Set: Target(self: DebuggerDisplayAttribute)=value

"""

 TargetTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the type name of the attribute's target.



Get: TargetTypeName(self: DebuggerDisplayAttribute) -> str



Set: TargetTypeName(self: DebuggerDisplayAttribute)=value

"""

 Type=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the string to display in the type column of the debugger variable windows.



Get: Type(self: DebuggerDisplayAttribute) -> str



Set: Type(self: DebuggerDisplayAttribute)=value

"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the string to display in the value column of the debugger variable windows.



Get: Value(self: DebuggerDisplayAttribute) -> str



"""





class InkCanvasStrokesReplacedEventArgs(EventArgs):
 """ Provides data for the System.Windows.Controls.InkCanvas.StrokesReplaced event. """
 NewStrokes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the new strokes of the System.Windows.Controls.InkCanvas.



Get: NewStrokes(self: InkCanvasStrokesReplacedEventArgs) -> StrokeCollection



"""

 PreviousStrokes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the previous strokes of the System.Windows.Controls.InkCanvas.



Get: PreviousStrokes(self: InkCanvasStrokesReplacedEventArgs) -> StrokeCollection



"""





# encoding: utf-8
# module System.Windows.Diagnostics calls itself Diagnostics
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class VisualDiagnostics(object):
 # no doc
 @staticmethod
 def GetXamlSourceInfo(obj):
  """ GetXamlSourceInfo(obj: object) -> XamlSourceInfo """
  pass
 VisualTreeChanged=None
 __all__=[
  'GetXamlSourceInfo',
  'VisualTreeChanged',
 ]


class VisualTreeChangeEventArgs(EventArgs):
 """ VisualTreeChangeEventArgs(parent: DependencyObject,child: DependencyObject,childIndex: int,changeType: VisualTreeChangeType) """
 @staticmethod
 def __new__(self,parent,child,childIndex,changeType):
  """ __new__(cls: type,parent: DependencyObject,child: DependencyObject,childIndex: int,changeType: VisualTreeChangeType) """
  pass
 ChangeType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ChangeType(self: VisualTreeChangeEventArgs) -> VisualTreeChangeType



"""

 Child=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Child(self: VisualTreeChangeEventArgs) -> DependencyObject



"""

 ChildIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ChildIndex(self: VisualTreeChangeEventArgs) -> int



"""

 Parent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Parent(self: VisualTreeChangeEventArgs) -> DependencyObject



"""



class VisualTreeChangeType(Enum,IComparable,IFormattable,IConvertible):
 """ enum VisualTreeChangeType,values: Add (0),Remove (1) """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Add=None
 Remove=None
 value__=None


class XamlSourceInfo(object):
 """ XamlSourceInfo(sourceUri: Uri,lineNumber: int,linePosition: int) """
 @staticmethod
 def __new__(self,sourceUri,lineNumber,linePosition):
  """ __new__(cls: type,sourceUri: Uri,lineNumber: int,linePosition: int) """
  pass
 LineNumber=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LineNumber(self: XamlSourceInfo) -> int



"""

 LinePosition=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LinePosition(self: XamlSourceInfo) -> int



"""

 SourceUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SourceUri(self: XamlSourceInfo) -> Uri



"""






class HttpListenerContext(object):
 """ Provides access to the request and response objects used by the System.Net.HttpListener class. This class cannot be inherited. """
 def AcceptWebSocketAsync(self,subProtocol,*__args):
  """
  AcceptWebSocketAsync(self: HttpListenerContext,subProtocol: str,receiveBufferSize: int,keepAliveInterval: TimeSpan) -> Task[HttpListenerWebSocketContext]

  AcceptWebSocketAsync(self: HttpListenerContext,subProtocol: str,receiveBufferSize: int,keepAliveInterval: TimeSpan,internalBuffer: ArraySegment[Byte]) -> Task[HttpListenerWebSocketContext]

  AcceptWebSocketAsync(self: HttpListenerContext,subProtocol: str) -> Task[HttpListenerWebSocketContext]

  AcceptWebSocketAsync(self: HttpListenerContext,subProtocol: str,keepAliveInterval: TimeSpan) -> Task[HttpListenerWebSocketContext]
  """
  pass
 Request=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Net.HttpListenerRequest that represents a client's request for a resource.



Get: Request(self: HttpListenerContext) -> HttpListenerRequest



"""

 Response=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Net.HttpListenerResponse object that will be sent to the client in response to the client's request.



Get: Response(self: HttpListenerContext) -> HttpListenerResponse



"""

 User=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an object used to obtain identity,authentication information,and security roles for the client whose request is represented by this System.Net.HttpListenerContext object.



Get: User(self: HttpListenerContext) -> IPrincipal



"""





class AppDomainSetup(object,IAppDomainSetup):
 """
 Represents assembly binding information that can be added to an instance of System.AppDomain.

 

 AppDomainSetup()

 AppDomainSetup(activationContext: ActivationContext)

 AppDomainSetup(activationArguments: ActivationArguments)
 """
 def GetConfigurationBytes(self):
  """
  GetConfigurationBytes(self: AppDomainSetup) -> Array[Byte]

  

   Returns the XML configuration information set by the 

    System.AppDomainSetup.SetConfigurationBytes(System.Byte[]) method,which overrides the 

    application's XML configuration information.

  

   Returns: An array that contains the XML configuration information that was set by the 

    System.AppDomainSetup.SetConfigurationBytes(System.Byte[]) method,or null if the 

    System.AppDomainSetup.SetConfigurationBytes(System.Byte[]) method has not been called.
  """
  pass
 def SetCompatibilitySwitches(self,switches):
  """ SetCompatibilitySwitches(self: AppDomainSetup,switches: IEnumerable[str]) """
  pass
 def SetConfigurationBytes(self,value):
  """
  SetConfigurationBytes(self: AppDomainSetup,value: Array[Byte])

   Provides XML configuration information for the application domain,overriding the application's 

    XML configuration information.

  

  

   value: An array that contains the XML configuration information to be used for the application domain.
  """
  pass
 def SetNativeFunction(self,functionName,functionVersion,functionPointer):
  """ SetNativeFunction(self: AppDomainSetup,functionName: str,functionVersion: int,functionPointer: IntPtr) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,activationContext: ActivationContext)

  __new__(cls: type,activationArguments: ActivationArguments)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 ActivationArguments=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets data about the activation of an application domain.



Get: ActivationArguments(self: AppDomainSetup) -> ActivationArguments



Set: ActivationArguments(self: AppDomainSetup)=value

"""

 AppDomainInitializer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.AppDomainInitializer delegate,which represents a callback method that is invoked when the application domain is initialized.



Get: AppDomainInitializer(self: AppDomainSetup) -> AppDomainInitializer



Set: AppDomainInitializer(self: AppDomainSetup)=value

"""

 AppDomainInitializerArguments=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the arguments passed to the callback method represented by the System.AppDomainInitializer delegate. The callback method is invoked when the application domain is initialized.



Get: AppDomainInitializerArguments(self: AppDomainSetup) -> Array[str]



Set: AppDomainInitializerArguments(self: AppDomainSetup)=value

"""

 AppDomainManagerAssembly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the display name of the assembly that provides the type of the application domain manager for application domains created using this System.AppDomainSetup object.



Get: AppDomainManagerAssembly(self: AppDomainSetup) -> str



Set: AppDomainManagerAssembly(self: AppDomainSetup)=value

"""

 AppDomainManagerType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the full name of the type that provides the application domain manager for application domains created using this System.AppDomainSetup object.



Get: AppDomainManagerType(self: AppDomainSetup) -> str



Set: AppDomainManagerType(self: AppDomainSetup)=value

"""

 ApplicationBase=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the directory containing the application.



Get: ApplicationBase(self: AppDomainSetup) -> str



Set: ApplicationBase(self: AppDomainSetup)=value

"""

 ApplicationName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the application.



Get: ApplicationName(self: AppDomainSetup) -> str



Set: ApplicationName(self: AppDomainSetup)=value

"""

 ApplicationTrust=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an object containing security and trust information.



Get: ApplicationTrust(self: AppDomainSetup) -> ApplicationTrust



Set: ApplicationTrust(self: AppDomainSetup)=value

"""

 CachePath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of an area specific to the application where files are shadow copied.



Get: CachePath(self: AppDomainSetup) -> str



Set: CachePath(self: AppDomainSetup)=value

"""

 ConfigurationFile=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the configuration file for an application domain.



Get: ConfigurationFile(self: AppDomainSetup) -> str



Set: ConfigurationFile(self: AppDomainSetup)=value

"""

 DisallowApplicationBaseProbing=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Specifies whether the application base path and private binary path are probed when searching for assemblies to load.



Get: DisallowApplicationBaseProbing(self: AppDomainSetup) -> bool



Set: DisallowApplicationBaseProbing(self: AppDomainSetup)=value

"""

 DisallowBindingRedirects=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether an application domain allows assembly binding redirection.



Get: DisallowBindingRedirects(self: AppDomainSetup) -> bool



Set: DisallowBindingRedirects(self: AppDomainSetup)=value

"""

 DisallowCodeDownload=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether HTTP download of assemblies is allowed for an application domain.



Get: DisallowCodeDownload(self: AppDomainSetup) -> bool



Set: DisallowCodeDownload(self: AppDomainSetup)=value

"""

 DisallowPublisherPolicy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the <publisherPolicy> section of the configuration file is applied to an application domain.



Get: DisallowPublisherPolicy(self: AppDomainSetup) -> bool



Set: DisallowPublisherPolicy(self: AppDomainSetup)=value

"""

 DynamicBase=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the base directory where the directory for dynamically generated files is located.



Get: DynamicBase(self: AppDomainSetup) -> str



Set: DynamicBase(self: AppDomainSetup)=value

"""

 LicenseFile=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the location of the license file associated with this domain.



Get: LicenseFile(self: AppDomainSetup) -> str



Set: LicenseFile(self: AppDomainSetup)=value

"""

 LoaderOptimization=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Specifies the optimization policy used to load an executable.



Get: LoaderOptimization(self: AppDomainSetup) -> LoaderOptimization



Set: LoaderOptimization(self: AppDomainSetup)=value

"""

 PartialTrustVisibleAssemblies=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a list of assemblies marked with the System.Security.PartialTrustVisibilityLevel.NotVisibleByDefault flag that are made visible to partial-trust code running in a sandboxed application domain.



Get: PartialTrustVisibleAssemblies(self: AppDomainSetup) -> Array[str]



Set: PartialTrustVisibleAssemblies(self: AppDomainSetup)=value

"""

 PrivateBinPath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the list of directories under the application base directory that are probed for private assemblies.



Get: PrivateBinPath(self: AppDomainSetup) -> str



Set: PrivateBinPath(self: AppDomainSetup)=value

"""

 PrivateBinPathProbe=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a string value that includes or excludes System.AppDomainSetup.ApplicationBase from the search path for the application,and searches only System.AppDomainSetup.PrivateBinPath.



Get: PrivateBinPathProbe(self: AppDomainSetup) -> str



Set: PrivateBinPathProbe(self: AppDomainSetup)=value

"""

 SandboxInterop=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether interface caching is disabled for interop calls in the application domain,so that a QueryInterface is performed on each call.



Get: SandboxInterop(self: AppDomainSetup) -> bool



Set: SandboxInterop(self: AppDomainSetup)=value

"""

 ShadowCopyDirectories=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the names of the directories containing assemblies to be shadow copied.



Get: ShadowCopyDirectories(self: AppDomainSetup) -> str



Set: ShadowCopyDirectories(self: AppDomainSetup)=value

"""

 ShadowCopyFiles=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a string that indicates whether shadow copying is turned on or off.



Get: ShadowCopyFiles(self: AppDomainSetup) -> str



Set: ShadowCopyFiles(self: AppDomainSetup)=value

"""

 TargetFrameworkName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: TargetFrameworkName(self: AppDomainSetup) -> str



Set: TargetFrameworkName(self: AppDomainSetup)=value

"""





class IFileReaderService:
 """ Defines a method that opens a file from the current directory. """
 def OpenFileFromSource(self,relativePath):
  """
  OpenFileFromSource(self: IFileReaderService,relativePath: str) -> Stream

  

   Opens a file from the current directory.

  

   relativePath: The file to open.

   Returns: A stream of the specified file.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class NotifyParentPropertyAttribute(Attribute,_Attribute):
 """
 Indicates that the parent property is notified when the value of the property that this attribute is applied to is modified. This class cannot be inherited.

 

 NotifyParentPropertyAttribute(notifyParent: bool)
 """
 def Equals(self,obj):
  """
  Equals(self: NotifyParentPropertyAttribute,obj: object) -> bool

  

   Gets a value indicating whether the specified object is the same as the current object.

  

   obj: The object to test for equality.

   Returns: true if the object is the same as this object; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: NotifyParentPropertyAttribute) -> int

  

   Gets the hash code for this object.

   Returns: The hash code for the object the attribute belongs to.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: NotifyParentPropertyAttribute) -> bool

  

   Gets a value indicating whether the current value of the attribute is the default value for the 

    attribute.

  

   Returns: true if the current value of the attribute is the default value of the attribute; otherwise,

    false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,notifyParent):
  """ __new__(cls: type,notifyParent: bool) """
  pass
 def __ne__(self,*args):
  pass
 NotifyParent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the parent property should be notified of changes to the value of the property.



Get: NotifyParent(self: NotifyParentPropertyAttribute) -> bool



"""


 Default=None
 No=None
 Yes=None




class DebuggerVisualizerAttribute(Attribute,_Attribute):
 """
 Specifies that the type has a visualizer. This class cannot be inherited.

 

 DebuggerVisualizerAttribute(visualizerTypeName: str)

 DebuggerVisualizerAttribute(visualizerTypeName: str,visualizerObjectSourceTypeName: str)

 DebuggerVisualizerAttribute(visualizerTypeName: str,visualizerObjectSource: Type)

 DebuggerVisualizerAttribute(visualizer: Type)

 DebuggerVisualizerAttribute(visualizer: Type,visualizerObjectSource: Type)

 DebuggerVisualizerAttribute(visualizer: Type,visualizerObjectSourceTypeName: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,visualizerTypeName: str)

  __new__(cls: type,visualizerTypeName: str,visualizerObjectSourceTypeName: str)

  __new__(cls: type,visualizerTypeName: str,visualizerObjectSource: Type)

  __new__(cls: type,visualizer: Type)

  __new__(cls: type,visualizer: Type,visualizerObjectSource: Type)

  __new__(cls: type,visualizer: Type,visualizerObjectSourceTypeName: str)
  """
  pass
 Description=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the description of the visualizer.



Get: Description(self: DebuggerVisualizerAttribute) -> str



Set: Description(self: DebuggerVisualizerAttribute)=value

"""

 Target=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the target type when the attribute is applied at the assembly level.



Get: Target(self: DebuggerVisualizerAttribute) -> Type



Set: Target(self: DebuggerVisualizerAttribute)=value

"""

 TargetTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the fully qualified type name when the attribute is applied at the assembly level.



Get: TargetTypeName(self: DebuggerVisualizerAttribute) -> str



Set: TargetTypeName(self: DebuggerVisualizerAttribute)=value

"""

 VisualizerObjectSourceTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the fully qualified type name of the visualizer object source.



Get: VisualizerObjectSourceTypeName(self: DebuggerVisualizerAttribute) -> str



"""

 VisualizerTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the fully qualified type name of the visualizer.



Get: VisualizerTypeName(self: DebuggerVisualizerAttribute) -> str



"""





class DownloadStringCompletedEventArgs(AsyncCompletedEventArgs):
 """ Provides data for the System.Net.WebClient.DownloadStringCompleted event. """
 Result=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the data that is downloaded by a erload:System.Net.WebClient.DownloadStringAsync method.



Get: Result(self: DownloadStringCompletedEventArgs) -> str



"""





class DisplayNameAttribute(Attribute,_Attribute):
 """
 Specifies the display name for a property,event,or public void method which takes no arguments.

 

 DisplayNameAttribute()

 DisplayNameAttribute(displayName: str)
 """
 def Equals(self,obj):
  """
  Equals(self: DisplayNameAttribute,obj: object) -> bool

  

   Determines whether two System.ComponentModel.DisplayNameAttribute instances are equal.

  

   obj: The System.ComponentModel.DisplayNameAttribute to test the value equality of.

   Returns: true if the value of the given object is equal to that of the current object; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DisplayNameAttribute) -> int

  

   Returns the hash code for this instance.

   Returns: A hash code for the current System.ComponentModel.DisplayNameAttribute.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: DisplayNameAttribute) -> bool

  

   Determines if this attribute is the default.

   Returns: true if the attribute is the default value for this attribute class; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,displayName=None):
  """
  __new__(cls: type)

  __new__(cls: type,displayName: str)
  """
  pass
 def __ne__(self,*args):
  pass
 DisplayName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the display name for a property,event,or public void method that takes no arguments stored in this attribute.



Get: DisplayName(self: DisplayNameAttribute) -> str



"""

 DisplayNameValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the display name.



"""


 Default=None




class GenericAce(object):
 """ Represents an Access Control Entry (ACE),and is the base class for all other ACE classes. """
 def Copy(self):
  """
  Copy(self: GenericAce) -> GenericAce

  

   Creates a deep copy of this Access Control Entry (ACE).

   Returns: The System.Security.AccessControl.GenericAce object that this method creates.
  """
  pass
 @staticmethod
 def CreateFromBinaryForm(binaryForm,offset):
  """
  CreateFromBinaryForm(binaryForm: Array[Byte],offset: int) -> GenericAce

  

   Creates a System.Security.AccessControl.GenericAce object from the specified binary data.

  

   binaryForm: The binary data from which to create the new System.Security.AccessControl.GenericAce object.

   offset: The offset at which to begin unmarshaling.

   Returns: The System.Security.AccessControl.GenericAce object this method creates.
  """
  pass
 def Equals(self,o):
  """
  Equals(self: GenericAce,o: object) -> bool

  

   Determines whether the specified System.Security.AccessControl.GenericAce object is equal to the 

    current System.Security.AccessControl.GenericAce object.

  

  

   o: The System.Security.AccessControl.GenericAce object to compare to the current 

    System.Security.AccessControl.GenericAce object.

  

   Returns: true if the specified System.Security.AccessControl.GenericAce object is equal to the current 

    System.Security.AccessControl.GenericAce object; otherwise,false.
  """
  pass
 def GetBinaryForm(self,binaryForm,offset):
  """
  GetBinaryForm(self: GenericAce,binaryForm: Array[Byte],offset: int)

   Marshals the contents of the System.Security.AccessControl.GenericAce object into the specified 

    byte array beginning at the specified offset.

  

  

   binaryForm: The byte array into which the contents of the System.Security.AccessControl.GenericAce is 

    marshaled.

  

   offset: The offset at which to start marshaling.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: GenericAce) -> int

  

   Serves as a hash function for the System.Security.AccessControl.GenericAce class. The  

    System.Security.AccessControl.GenericAce.GetHashCode method is suitable for use in hashing 

    algorithms and data structures like a hash table.

  

   Returns: A hash code for the current System.Security.AccessControl.GenericAce object.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __ne__(self,*args):
  pass
 AceFlags=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Security.AccessControl.AceFlags associated with this System.Security.AccessControl.GenericAce object.



Get: AceFlags(self: GenericAce) -> AceFlags



Set: AceFlags(self: GenericAce)=value

"""

 AceType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type of this Access Control Entry (ACE).



Get: AceType(self: GenericAce) -> AceType



"""

 AuditFlags=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the audit information associated with this Access Control Entry (ACE).



Get: AuditFlags(self: GenericAce) -> AuditFlags



"""

 BinaryLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length,in bytes,of the binary representation of the current System.Security.AccessControl.GenericAce object. This length should be used before marshaling the ACL into a binary array with the System.Security.AccessControl.GenericAce.GetBinaryForm method.



Get: BinaryLength(self: GenericAce) -> int



"""

 InheritanceFlags=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets flags that specify the inheritance properties of this Access Control Entry (ACE).



Get: InheritanceFlags(self: GenericAce) -> InheritanceFlags



"""

 IsInherited=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a Boolean value that specifies whether this Access Control Entry (ACE) is inherited or is set explicitly.



Get: IsInherited(self: GenericAce) -> bool



"""

 PropagationFlags=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets flags that specify the inheritance propagation properties of this Access Control Entry (ACE).



Get: PropagationFlags(self: GenericAce) -> PropagationFlags



"""





class DnsPermission(CodeAccessPermission,IPermission,ISecurityEncodable,IStackWalk,IUnrestrictedPermission):
 """
 Controls rights to access Domain Name System (DNS) servers on the network.

 

 DnsPermission(state: PermissionState)
 """
 def Copy(self):
  """
  Copy(self: DnsPermission) -> IPermission

  

   Creates an identical copy of the current permission instance.

   Returns: A new instance of the System.Net.DnsPermission class that is an identical copy of the current 

    instance.
  """
  pass
 def FromXml(self,securityElement):
  """
  FromXml(self: DnsPermission,securityElement: SecurityElement)

   Reconstructs a System.Net.DnsPermission instance from an XML encoding.

  

   securityElement: The XML encoding to use to reconstruct the System.Net.DnsPermission instance.
  """
  pass
 def Intersect(self,target):
  """
  Intersect(self: DnsPermission,target: IPermission) -> IPermission

  

   Creates a permission instance that is the intersection of the current permission instance and 

    the specified permission instance.

  

  

   target: The System.Net.DnsPermission instance to intersect with the current instance.

   Returns: A System.Net.DnsPermission instance that represents the intersection of the current 

    System.Net.DnsPermission instance with the specified System.Net.DnsPermission instance,or null 

    if the intersection is empty. If both the current instance and target are unrestricted,this 

    method returns a new System.Net.DnsPermission instance that is unrestricted; otherwise,it 

    returns null.
  """
  pass
 def IsSubsetOf(self,target):
  """
  IsSubsetOf(self: DnsPermission,target: IPermission) -> bool

  

   Determines whether the current permission instance is a subset of the specified permission 

    instance.

  

  

   target: The second System.Net.DnsPermission instance to be tested for the subset relationship.

   Returns: false if the current instance is unrestricted and target is either null or unrestricted; 

    otherwise,true.
  """
  pass
 def IsUnrestricted(self):
  """
  IsUnrestricted(self: DnsPermission) -> bool

  

   Checks the overall permission state of the object.

   Returns: true if the System.Net.DnsPermission instance was created with 

    System.Security.Permissions.PermissionState.Unrestricted; otherwise,false.
  """
  pass
 def ToXml(self):
  """
  ToXml(self: DnsPermission) -> SecurityElement

  

   Creates an XML encoding of a System.Net.DnsPermission instance and its current state.

   Returns: A System.Security.SecurityElement instance that contains an XML-encoded representation of the 

    security object,including state information.
  """
  pass
 def Union(self,target):
  """
  Union(self: DnsPermission,target: IPermission) -> IPermission

  

   Creates a permission instance that is the union of the current permission instance and the 

    specified permission instance.

  

  

   target: The System.Net.DnsPermission instance to combine with the current instance.

   Returns: A System.Net.DnsPermission instance that represents the union of the current 

    System.Net.DnsPermission instance with the specified System.Net.DnsPermission instance. If 

    target is null,this method returns a copy of the current instance. If the current instance or 

    target is unrestricted,this method returns a System.Net.DnsPermission instance that is 

    unrestricted; otherwise,it returns a System.Net.DnsPermission instance that is restricted.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,state):
  """ __new__(cls: type,state: PermissionState) """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass



class DataGridViewCellCollection(BaseCollection,ICollection,IEnumerable,IList):
 """
 Represents a collection of cells in a System.Windows.Forms.DataGridViewRow.

 

 DataGridViewCellCollection(dataGridViewRow: DataGridViewRow)
 """
 def Add(self,dataGridViewCell):
  """
  Add(self: DataGridViewCellCollection,dataGridViewCell: DataGridViewCell) -> int

  

   Adds a cell to the collection.

  

   dataGridViewCell: A System.Windows.Forms.DataGridViewCell to add to the collection.

   Returns: The position in which to insert the new element.
  """
  pass
 def AddRange(self,dataGridViewCells):
  """
  AddRange(self: DataGridViewCellCollection,*dataGridViewCells: Array[DataGridViewCell])

   Adds an array of cells to the collection.

  

   dataGridViewCells: The array of System.Windows.Forms.DataGridViewCell objects to add to the collection.
  """
  pass
 def Clear(self):
  """
  Clear(self: DataGridViewCellCollection)

   Clears all cells from the collection.
  """
  pass
 def Contains(self,dataGridViewCell):
  """
  Contains(self: DataGridViewCellCollection,dataGridViewCell: DataGridViewCell) -> bool

  

   Determines whether the specified cell is contained in the collection.

  

   dataGridViewCell: A System.Windows.Forms.DataGridViewCell to locate in the collection.

   Returns: true if dataGridViewCell is in the collection; otherwise,false.
  """
  pass
 def CopyTo(self,*__args):
  """
  CopyTo(self: DataGridViewCellCollection,array: Array[DataGridViewCell],index: int)

   Copies the entire collection of cells into an array at a specified location within the array.

  

   array: The destination array to which the contents will be copied.

   index: The index of the element in array at which to start copying.
  """
  pass
 def IndexOf(self,dataGridViewCell):
  """
  IndexOf(self: DataGridViewCellCollection,dataGridViewCell: DataGridViewCell) -> int

  

   Returns the index of the specified cell.

  

   dataGridViewCell: The cell to locate in the collection.

   Returns: The zero-based index of the value of dataGridViewCell parameter,if it is found in the 

    collection; otherwise,-1.
  """
  pass
 def Insert(self,index,dataGridViewCell):
  """
  Insert(self: DataGridViewCellCollection,index: int,dataGridViewCell: DataGridViewCell)

   Inserts a cell into the collection at the specified index.

  

   index: The zero-based index at which to place dataGridViewCell.

   dataGridViewCell: The System.Windows.Forms.DataGridViewCell to insert.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: DataGridViewCellCollection,e: CollectionChangeEventArgs)

   Raises the System.Windows.Forms.DataGridViewCellCollection.CollectionChanged event.

  

   e: A System.ComponentModel.CollectionChangeEventArgs that contains the event data.
  """
  pass
 def Remove(self,cell):
  """
  Remove(self: DataGridViewCellCollection,cell: DataGridViewCell)

   Removes the specified cell from the collection.

  

   cell: The System.Windows.Forms.DataGridViewCell to remove from the collection.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: DataGridViewCellCollection,index: int)

   Removes the cell at the specified index.

  

   index: The zero-based index of the System.Windows.Forms.DataGridViewCell to be removed.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,dataGridViewRow):
  """ __new__(cls: type,dataGridViewRow: DataGridViewRow) """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]=x.__setitem__(i,y) <==> x[i]= """
  pass
 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an System.Collections.ArrayList containing System.Windows.Forms.DataGridViewCellCollection objects.



"""


 CollectionChanged=None




"""Prepare and compile script types."""
from pyrevit import coreutils
from pyrevit.coreutils import logger

import pyrevit.extensions as exts

from pyrevit import runtime
from pyrevit.runtime import bundletypemaker
from pyrevit.runtime import pythontypemaker
from pyrevit.runtime import dynamotypemaker
from pyrevit.runtime import invoketypemaker
from pyrevit.runtime import urltypemaker


#pylint: disable=W0703,C0302,C0103
mlogger = logger.get_logger(__name__)


def create_avail_type(extension, cmd_component, module_builder=None):
    if cmd_component.type_id == exts.LINK_BUTTON_POSTFIX:
        mlogger.debug(
            'Skipped creating availability type for: %s', cmd_component
            )
        return

    # create command availability class for this command
    mlogger.debug('Creating availability type for: %s', cmd_component)
    # set the name of the created type
    cmd_component.avail_class_name = \
            cmd_component.class_name + runtime.CMD_AVAIL_NAME_POSTFIX

    if module_builder:
        context_str = cmd_component.context.lower()

        if context_str == exts.CTX_SELETION:
            bundletypemaker.create_selection_avail_type(
                module_builder=module_builder,
                cmd_component=cmd_component
                )

        elif context_str == exts.CTX_ZERODOC:
            bundletypemaker.create_zerodoc_avail_type(
                module_builder=module_builder,
                cmd_component=cmd_component
                )

        else:
            bundletypemaker.create_extended_avail_type(
                module_builder=module_builder,
                cmd_component=cmd_component
                )

        mlogger.debug(
            'Successfully created availability type for: %s', cmd_component)


def create_exec_types(extension, cmd_component, module_builder=None):
    mlogger.debug('Command language is: %s', cmd_component.script_language)
    # set the name of the created type
    cmd_component.class_name = cmd_component.unique_name

    if module_builder:
        ### create the executor types
        ## first highly custom button types
        # if invoke
        if cmd_component.type_id == exts.INVOKE_BUTTON_POSTFIX:
            invoketypemaker.create_executor_type(
                extension,
                module_builder,
                cmd_component
                )
        # if link
        elif cmd_component.type_id == exts.LINK_BUTTON_POSTFIX:
            # link buttons don't need types
            mlogger.debug('Skipped creating executor type for: %s',
                          cmd_component)
        # if content
        elif cmd_component.type_id == exts.CONTENT_BUTTON_POSTFIX:
            # link buttons don't need types
            bundletypemaker.create_executor_type(
                extension,
                module_builder,
                cmd_component
                )
        # if url
        elif cmd_component.type_id == exts.URL_BUTTON_POSTFIX:
            urltypemaker.create_executor_type(
                extension,
                module_builder,
                cmd_component
                )
        ## now language based button types
        # if python
        elif cmd_component.script_language == exts.PYTHON_LANG:
            pythontypemaker.create_executor_type(
                extension,
                module_builder,
                cmd_component
                )
        # if dynamo
        elif cmd_component.script_language == exts.DYNAMO_LANG:
            dynamotypemaker.create_executor_type(
                extension,
                module_builder,
                cmd_component
                )
        # if anything else
        else:
            bundletypemaker.create_executor_type(
                extension,
                module_builder,
                cmd_component
                )


# public base class maker function ---------------------------------------------
def make_bundle_types(extension, cmd_component, module_builder=None):
    """Create the types for the bundle.

    Args:
        extension (pyrevit.extensions.components.Extension): pyRevit extension
        cmd_component (pyrevit.extensions.genericcomps.GenericUICommand):
            command
        module_builder (ModuleBuilder): module builder.
    """
    # make command interface type for the given command
    try:
        create_exec_types(extension, cmd_component, module_builder)
    except Exception as createtype_err:
        mlogger.error('Error creating appropriate exec types for: %s | %s',
                      cmd_component, createtype_err)
    # create availability types if necessary
    if cmd_component.context:
        try:
            create_avail_type(extension, cmd_component, module_builder)
        except Exception as createtype_err:
            mlogger.error('Error creating appropriate avail types for: %s | %s',
                          cmd_component, createtype_err)



class Size(object):
 """
 Stores an ordered pair of integers,which specify a System.Drawing.Size.Height and System.Drawing.Size.Width.

 

 Size(pt: Point)

 Size(width: int,height: int)
 """
 @staticmethod
 def Add(sz1,sz2):
  """
  Add(sz1: Size,sz2: Size) -> Size

  

   Adds the width and height of one System.Drawing.Size structure to the width and height of 

    another System.Drawing.Size structure.

  

  

   sz1: The first System.Drawing.Size structure to add.

   sz2: The second System.Drawing.Size structure to add.

   Returns: A System.Drawing.Size structure that is the result of the addition operation.
  """
  pass
 @staticmethod
 def Ceiling(value):
  """
  Ceiling(value: SizeF) -> Size

  

   Converts the specified System.Drawing.SizeF structure to a System.Drawing.Size structure by 

    rounding the values of the System.Drawing.Size structure to the next higher integer values.

  

  

   value: The System.Drawing.SizeF structure to convert.

   Returns: The System.Drawing.Size structure this method converts to.
  """
  pass
 def Equals(self,obj):
  """
  Equals(self: Size,obj: object) -> bool

  

   Tests to see whether the specified object is a System.Drawing.Size structure with the same 

    dimensions as this System.Drawing.Size structure.

  

  

   obj: The System.Object to test.

   Returns: true if obj is a System.Drawing.Size and has the same width and height as this 

    System.Drawing.Size; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Size) -> int

  

   Returns a hash code for this System.Drawing.Size structure.

   Returns: An integer value that specifies a hash value for this System.Drawing.Size structure.
  """
  pass
 @staticmethod
 def Round(value):
  """
  Round(value: SizeF) -> Size

  

   Converts the specified System.Drawing.SizeF structure to a System.Drawing.Size structure by 

    rounding the values of the System.Drawing.SizeF structure to the nearest integer values.

  

  

   value: The System.Drawing.SizeF structure to convert.

   Returns: The System.Drawing.Size structure this method converts to.
  """
  pass
 @staticmethod
 def Subtract(sz1,sz2):
  """
  Subtract(sz1: Size,sz2: Size) -> Size

  

   Subtracts the width and height of one System.Drawing.Size structure from the width and height of 

    another System.Drawing.Size structure.

  

  

   sz1: The System.Drawing.Size structure on the left side of the subtraction operator.

   sz2: The System.Drawing.Size structure on the right side of the subtraction operator.

   Returns: A System.Drawing.Size structure that is a result of the subtraction operation.
  """
  pass
 def ToString(self):
  """
  ToString(self: Size) -> str

  

   Creates a human-readable string that represents this System.Drawing.Size structure.

   Returns: A string that represents this System.Drawing.Size.
  """
  pass
 @staticmethod
 def Truncate(value):
  """
  Truncate(value: SizeF) -> Size

  

   Converts the specified System.Drawing.SizeF structure to a System.Drawing.Size structure by 

    truncating the values of the System.Drawing.SizeF structure to the next lower integer values.

  

  

   value: The System.Drawing.SizeF structure to convert.

   Returns: The System.Drawing.Size structure this method converts to.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__[Size]() -> Size

  

  __new__(cls: type,pt: Point)

  __new__(cls: type,width: int,height: int)
  """
  pass
 def __ne__(self,*args):
  pass
 def __radd__(self,*args):
  """
  __radd__(sz1: Size,sz2: Size) -> Size

  

   Adds the width and height of one System.Drawing.Size structure to the width and height of 

    another System.Drawing.Size structure.

  

  

   sz1: The first System.Drawing.Size to add.

   sz2: The second System.Drawing.Size to add.

   Returns: A System.Drawing.Size structure that is the result of the addition operation.
  """
  pass
 def __rsub__(self,*args):
  """
  __rsub__(sz1: Size,sz2: Size) -> Size

  

   Subtracts the width and height of one System.Drawing.Size structure from the width and height of 

    another System.Drawing.Size structure.

  

  

   sz1: The System.Drawing.Size structure on the left side of the subtraction operator.

   sz2: The System.Drawing.Size structure on the right side of the subtraction operator.

   Returns: A System.Drawing.Size structure that is the result of the subtraction operation.
  """
  pass
 def __sub__(self,*args):
  """ x.__sub__(y) <==> x-y """
  pass
 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the vertical component of this System.Drawing.Size structure.



Get: Height(self: Size) -> int



Set: Height(self: Size)=value

"""

 IsEmpty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Tests whether this System.Drawing.Size structure has width and height of 0.



Get: IsEmpty(self: Size) -> bool



"""

 Width=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the horizontal component of this System.Drawing.Size structure.



Get: Width(self: Size) -> int



Set: Width(self: Size)=value

"""


 Empty=None




class GCHandle(object):
 """ Provides a way to access a managed object from unmanaged memory. """
 def AddrOfPinnedObject(self):
  """
  AddrOfPinnedObject(self: GCHandle) -> IntPtr

  

   Retrieves the address of an object in a System.Runtime.InteropServices.GCHandleType.Pinned 

    handle.

  

   Returns: The address of the of the Pinned object as an System.IntPtr.
  """
  pass
 @staticmethod
 def Alloc(value,type=None):
  """
  Alloc(value: object,type: GCHandleType) -> GCHandle

  

   Allocates a handle of the specified type for the specified object.

  

   value: The object that uses the System.Runtime.InteropServices.GCHandle.

   type: One of the System.Runtime.InteropServices.GCHandleType values,indicating the type of 

    System.Runtime.InteropServices.GCHandle to create.

  

   Returns: A new System.Runtime.InteropServices.GCHandle of the specified type. This 

    System.Runtime.InteropServices.GCHandle must be released with 

    System.Runtime.InteropServices.GCHandle.Free when it is no longer needed.

  

  Alloc(value: object) -> GCHandle

  

   Allocates a System.Runtime.InteropServices.GCHandleType.Normal handle for the specified object.

  

   value: The object that uses the System.Runtime.InteropServices.GCHandle.

   Returns: A new System.Runtime.InteropServices.GCHandle that protects the object from garbage collection. 

    This System.Runtime.InteropServices.GCHandle must be released with 

    System.Runtime.InteropServices.GCHandle.Free when it is no longer needed.
  """
  pass
 def Equals(self,o):
  """
  Equals(self: GCHandle,o: object) -> bool

  

   Determines whether the specified System.Runtime.InteropServices.GCHandle object is equal to the 

    current System.Runtime.InteropServices.GCHandle object.

  

  

   o: The System.Runtime.InteropServices.GCHandle object to compare with the current 

    System.Runtime.InteropServices.GCHandle object.

  

   Returns: true if the specified System.Runtime.InteropServices.GCHandle object is equal to the current 

    System.Runtime.InteropServices.GCHandle object; otherwise,false.
  """
  pass
 def Free(self):
  """
  Free(self: GCHandle)

   Releases a System.Runtime.InteropServices.GCHandle.
  """
  pass
 @staticmethod
 def FromIntPtr(value):
  """
  FromIntPtr(value: IntPtr) -> GCHandle

  

   Returns a new System.Runtime.InteropServices.GCHandle object created from a handle to a managed 

    object.

  

  

   value: An System.IntPtr handle to a managed object to create a System.Runtime.InteropServices.GCHandle 

    object from.

  

   Returns: A new System.Runtime.InteropServices.GCHandle object that corresponds to the value parameter.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: GCHandle) -> int

  

   Returns an identifier for the current System.Runtime.InteropServices.GCHandle object.

   Returns: An identifier for the current System.Runtime.InteropServices.GCHandle object.
  """
  pass
 @staticmethod
 def ToIntPtr(value):
  """
  ToIntPtr(value: GCHandle) -> IntPtr

  

   Returns the internal integer representation of a System.Runtime.InteropServices.GCHandle object.

  

   value: A System.Runtime.InteropServices.GCHandle object to retrieve an internal integer representation 

    from.

  

   Returns: An System.IntPtr object that represents a System.Runtime.InteropServices.GCHandle object.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __ne__(self,*args):
  pass
 IsAllocated=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the handle is allocated.



Get: IsAllocated(self: GCHandle) -> bool



"""

 Target=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object this handle represents.



Get: Target(self: GCHandle) -> object



Set: Target(self: GCHandle)=value

"""





class CollectionChangeEventArgs(EventArgs):
 """
 Provides data for the System.Data.DataColumnCollection.CollectionChanged event.

 

 CollectionChangeEventArgs(action: CollectionChangeAction,element: object)
 """
 @staticmethod
 def __new__(self,action,element):
  """ __new__(cls: type,action: CollectionChangeAction,element: object) """
  pass
 Action=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an action that specifies how the collection changed.



Get: Action(self: CollectionChangeEventArgs) -> CollectionChangeAction



"""

 Element=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the instance of the collection with the change.



Get: Element(self: CollectionChangeEventArgs) -> object



"""





class WindowsFormsSynchronizationContext(SynchronizationContext,IDisposable):
 """
 Provides a synchronization context for the Windows Forms application model.

 

 WindowsFormsSynchronizationContext()
 """
 def CreateCopy(self):
  """
  CreateCopy(self: WindowsFormsSynchronizationContext) -> SynchronizationContext

  

   Copies the synchronization context.

   Returns: A copy of the synchronization context.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: WindowsFormsSynchronizationContext)

   Releases all resources used by the System.Windows.Forms.WindowsFormsSynchronizationContext.
  """
  pass
 def Post(self,d,state):
  """
  Post(self: WindowsFormsSynchronizationContext,d: SendOrPostCallback,state: object)

   Dispatches an asynchronous message to a synchronization context.

  

   d: The System.Threading.SendOrPostCallback delegate to call.

   state: The object passed to the delegate.
  """
  pass
 def Send(self,d,state):
  """
  Send(self: WindowsFormsSynchronizationContext,d: SendOrPostCallback,state: object)

   Dispatches a synchronous message to a synchronization context

  

   d: The System.Threading.SendOrPostCallback delegate to call.

   state: The object passed to the delegate.
  """
  pass
 def SetWaitNotificationRequired(self,*args):
  """
  SetWaitNotificationRequired(self: SynchronizationContext)

   Sets notification that wait notification is required and prepares the callback method so it can 

    be called more reliably when a wait occurs.
  """
  pass
 @staticmethod
 def Uninstall():
  """
  Uninstall()

   Uninstalls the currently installed System.Windows.Forms.WindowsFormsSynchronizationContext and 

    replaces it with the previously installed context.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 AutoInstall=True


# variables with complex values




class UCOMITypeComp:
 """ Use System.Runtime.InteropServices.ComTypes.ITypeComp instead. """
 def Bind(self,szName,lHashVal,wFlags,ppTInfo,pDescKind,pBindPtr):
  """
  Bind(self: UCOMITypeComp,szName: str,lHashVal: int,wFlags: Int16) -> (UCOMITypeInfo,DESCKIND,BINDPTR)

  

   Maps a name to a member of a type,or binds global variables and functions contained in a type 

    library.

  

  

   szName: The name to bind.

   lHashVal: A hash value for szName computed by LHashValOfNameSys.

   wFlags: A flags word containing one or more of the invoke flags defined in the INVOKEKIND enumeration.
  """
  pass
 def BindType(self,szName,lHashVal,ppTInfo,ppTComp):
  """
  BindType(self: UCOMITypeComp,szName: str,lHashVal: int) -> (UCOMITypeInfo,UCOMITypeComp)

  

   Binds to the type descriptions contained within a type library.

  

   szName: The name to bind.

   lHashVal: A hash value for szName determined by LHashValOfNameSys.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



# encoding: utf-8
# module System.Runtime calls itself Runtime
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class AssemblyTargetedPatchBandAttribute(Attribute,_Attribute):
 """
 Specifies patch band information for targeted patching of the .NET Framework.

 

 AssemblyTargetedPatchBandAttribute(targetedPatchBand: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,targetedPatchBand):
  """ __new__(cls: type,targetedPatchBand: str) """
  pass
 TargetedPatchBand=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the patch band.



Get: TargetedPatchBand(self: AssemblyTargetedPatchBandAttribute) -> str



"""



class GCLargeObjectHeapCompactionMode(Enum,IComparable,IFormattable,IConvertible):
 """ enum GCLargeObjectHeapCompactionMode,values: CompactOnce (2),Default (1) """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 CompactOnce=None
 Default=None
 value__=None


class GCLatencyMode(Enum,IComparable,IFormattable,IConvertible):
 """
 Adjusts the time that the garbage collector intrudes in your application.

 

 enum GCLatencyMode,values: Batch (0),Interactive (1),LowLatency (2),NoGCRegion (4),SustainedLowLatency (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Batch=None
 Interactive=None
 LowLatency=None
 NoGCRegion=None
 SustainedLowLatency=None
 value__=None


class GCSettings(object):
 """ Specifies the garbage collection settings for the current process. """
 IsServerGC=False
 LargeObjectHeapCompactionMode=None
 LatencyMode=None
 __all__=[]


class MemoryFailPoint(CriticalFinalizerObject,IDisposable):
 """
 Checks for sufficient memory resources prior to execution. This class cannot be inherited.

 

 MemoryFailPoint(sizeInMegabytes: int)
 """
 def Dispose(self):
  """
  Dispose(self: MemoryFailPoint)

   Releases all resources used by the System.Runtime.MemoryFailPoint.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,sizeInMegabytes):
  """ __new__(cls: type,sizeInMegabytes: int) """
  pass

class ProfileOptimization(object):
 # no doc
 @staticmethod
 def SetProfileRoot(directoryPath):
  """ SetProfileRoot(directoryPath: str) """
  pass
 @staticmethod
 def StartProfile(profile):
  """ StartProfile(profile: str) """
  pass
 __all__=[
  'SetProfileRoot',
  'StartProfile',
 ]


class TargetedPatchingOptOutAttribute(Attribute,_Attribute):
 """
 Indicates that the .NET Framework class library method to which this attribute is applied is unlikely to be affected by servicing releases,and therefore is eligible to be inlined across Native Image Generator (NGen) images.

 

 TargetedPatchingOptOutAttribute(reason: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,reason):
  """ __new__(cls: type,reason: str) """
  pass
 Reason=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the reason why the method to which this attribute is applied is considered to be eligible for inlining across Native Image Generator (NGen) images.



Get: Reason(self: TargetedPatchingOptOutAttribute) -> str



"""



# variables with complex values




# encoding: utf-8
# module System.Security.Claims calls itself Claims
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class Claim(object):
 """
 Claim(reader: BinaryReader)

 Claim(reader: BinaryReader,subject: ClaimsIdentity)

 Claim(type: str,value: str)

 Claim(type: str,value: str,valueType: str)

 Claim(type: str,value: str,valueType: str,issuer: str)

 Claim(type: str,value: str,valueType: str,issuer: str,originalIssuer: str)

 Claim(type: str,value: str,valueType: str,issuer: str,originalIssuer: str,subject: ClaimsIdentity)
 """
 def Clone(self,identity=None):
  """
  Clone(self: Claim,identity: ClaimsIdentity) -> Claim

  Clone(self: Claim) -> Claim
  """
  pass
 def ToString(self):
  """ ToString(self: Claim) -> str """
  pass
 def WriteTo(self,writer):
  """ WriteTo(self: Claim,writer: BinaryWriter) """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,reader: BinaryReader)

  __new__(cls: type,reader: BinaryReader,subject: ClaimsIdentity)

  __new__(cls: type,type: str,value: str)

  __new__(cls: type,type: str,value: str,valueType: str)

  __new__(cls: type,type: str,value: str,valueType: str,issuer: str)

  __new__(cls: type,type: str,value: str,valueType: str,issuer: str,originalIssuer: str)

  __new__(cls: type,type: str,value: str,valueType: str,issuer: str,originalIssuer: str,subject: ClaimsIdentity)

  __new__(cls: type,other: Claim)

  __new__(cls: type,other: Claim,subject: ClaimsIdentity)
  """
  pass
 CustomSerializationData=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Issuer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Issuer(self: Claim) -> str



"""

 OriginalIssuer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: OriginalIssuer(self: Claim) -> str



"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Properties(self: Claim) -> IDictionary[str,str]



"""

 Subject=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Subject(self: Claim) -> ClaimsIdentity



"""

 Type=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Type(self: Claim) -> str



"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Value(self: Claim) -> str



"""

 ValueType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ValueType(self: Claim) -> str



"""



class ClaimsIdentity(object,IIdentity):
 """
 ClaimsIdentity()

 ClaimsIdentity(identity: IIdentity)

 ClaimsIdentity(claims: IEnumerable[Claim])

 ClaimsIdentity(authenticationType: str)

 ClaimsIdentity(claims: IEnumerable[Claim],authenticationType: str)

 ClaimsIdentity(identity: IIdentity,claims: IEnumerable[Claim])

 ClaimsIdentity(authenticationType: str,nameType: str,roleType: str)

 ClaimsIdentity(claims: IEnumerable[Claim],authenticationType: str,nameType: str,roleType: str)

 ClaimsIdentity(identity: IIdentity,claims: IEnumerable[Claim],authenticationType: str,nameType: str,roleType: str)

 ClaimsIdentity(reader: BinaryReader)
 """
 def AddClaim(self,claim):
  """ AddClaim(self: ClaimsIdentity,claim: Claim) """
  pass
 def AddClaims(self,claims):
  """ AddClaims(self: ClaimsIdentity,claims: IEnumerable[Claim]) """
  pass
 def Clone(self):
  """ Clone(self: ClaimsIdentity) -> ClaimsIdentity """
  pass
 def CreateClaim(self,*args):
  """ CreateClaim(self: ClaimsIdentity,reader: BinaryReader) -> Claim """
  pass
 def FindAll(self,*__args):
  """
  FindAll(self: ClaimsIdentity,type: str) -> IEnumerable[Claim]

  FindAll(self: ClaimsIdentity,match: Predicate[Claim]) -> IEnumerable[Claim]
  """
  pass
 def FindFirst(self,*__args):
  """
  FindFirst(self: ClaimsIdentity,type: str) -> Claim

  FindFirst(self: ClaimsIdentity,match: Predicate[Claim]) -> Claim
  """
  pass
 def GetObjectData(self,*args):
  """ GetObjectData(self: ClaimsIdentity,info: SerializationInfo,context: StreamingContext) """
  pass
 def HasClaim(self,*__args):
  """
  HasClaim(self: ClaimsIdentity,type: str,value: str) -> bool

  HasClaim(self: ClaimsIdentity,match: Predicate[Claim]) -> bool
  """
  pass
 def RemoveClaim(self,claim):
  """ RemoveClaim(self: ClaimsIdentity,claim: Claim) """
  pass
 def TryRemoveClaim(self,claim):
  """ TryRemoveClaim(self: ClaimsIdentity,claim: Claim) -> bool """
  pass
 def WriteTo(self,writer):
  """ WriteTo(self: ClaimsIdentity,writer: BinaryWriter) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,identity: IIdentity)

  __new__(cls: type,claims: IEnumerable[Claim])

  __new__(cls: type,authenticationType: str)

  __new__(cls: type,claims: IEnumerable[Claim],authenticationType: str)

  __new__(cls: type,identity: IIdentity,claims: IEnumerable[Claim])

  __new__(cls: type,authenticationType: str,nameType: str,roleType: str)

  __new__(cls: type,claims: IEnumerable[Claim],authenticationType: str,nameType: str,roleType: str)

  __new__(cls: type,identity: IIdentity,claims: IEnumerable[Claim],authenticationType: str,nameType: str,roleType: str)

  __new__(cls: type,reader: BinaryReader)

  __new__(cls: type,other: ClaimsIdentity)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)

  __new__(cls: type,info: SerializationInfo)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Actor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Actor(self: ClaimsIdentity) -> ClaimsIdentity



Set: Actor(self: ClaimsIdentity)=value

"""

 AuthenticationType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: AuthenticationType(self: ClaimsIdentity) -> str



"""

 BootstrapContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: BootstrapContext(self: ClaimsIdentity) -> object



Set: BootstrapContext(self: ClaimsIdentity)=value

"""

 Claims=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Claims(self: ClaimsIdentity) -> IEnumerable[Claim]



"""

 CustomSerializationData=property(lambda self: object(),lambda self,v: None,lambda self: None)

 IsAuthenticated=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsAuthenticated(self: ClaimsIdentity) -> bool



"""

 Label=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Label(self: ClaimsIdentity) -> str



Set: Label(self: ClaimsIdentity)=value

"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Name(self: ClaimsIdentity) -> str



"""

 NameClaimType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: NameClaimType(self: ClaimsIdentity) -> str



"""

 RoleClaimType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: RoleClaimType(self: ClaimsIdentity) -> str



"""


 DefaultIssuer='LOCAL AUTHORITY'
 DefaultNameClaimType='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/name'
 DefaultRoleClaimType='http://schemas.microsoft.com/ws/2008/06/identity/claims/role'


class ClaimsPrincipal(object,IPrincipal):
 """
 ClaimsPrincipal()

 ClaimsPrincipal(identity: IIdentity)

 ClaimsPrincipal(identities: IEnumerable[ClaimsIdentity])

 ClaimsPrincipal(principal: IPrincipal)

 ClaimsPrincipal(reader: BinaryReader)
 """
 def AddIdentities(self,identities):
  """ AddIdentities(self: ClaimsPrincipal,identities: IEnumerable[ClaimsIdentity]) """
  pass
 def AddIdentity(self,identity):
  """ AddIdentity(self: ClaimsPrincipal,identity: ClaimsIdentity) """
  pass
 def Clone(self):
  """ Clone(self: ClaimsPrincipal) -> ClaimsPrincipal """
  pass
 def CreateClaimsIdentity(self,*args):
  """ CreateClaimsIdentity(self: ClaimsPrincipal,reader: BinaryReader) -> ClaimsIdentity """
  pass
 def FindAll(self,*__args):
  """
  FindAll(self: ClaimsPrincipal,type: str) -> IEnumerable[Claim]

  FindAll(self: ClaimsPrincipal,match: Predicate[Claim]) -> IEnumerable[Claim]
  """
  pass
 def FindFirst(self,*__args):
  """
  FindFirst(self: ClaimsPrincipal,type: str) -> Claim

  FindFirst(self: ClaimsPrincipal,match: Predicate[Claim]) -> Claim
  """
  pass
 def GetObjectData(self,*args):
  """ GetObjectData(self: ClaimsPrincipal,info: SerializationInfo,context: StreamingContext) """
  pass
 def HasClaim(self,*__args):
  """
  HasClaim(self: ClaimsPrincipal,type: str,value: str) -> bool

  HasClaim(self: ClaimsPrincipal,match: Predicate[Claim]) -> bool
  """
  pass
 def IsInRole(self,role):
  """ IsInRole(self: ClaimsPrincipal,role: str) -> bool """
  pass
 def PrimaryIdentitySelector(self,*args):
  """ Func[IEnumerable[ClaimsIdentity],ClaimsIdentity](object: object,method: IntPtr) """
  pass
 def WriteTo(self,writer):
  """ WriteTo(self: ClaimsPrincipal,writer: BinaryWriter) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,identities: IEnumerable[ClaimsIdentity])

  __new__(cls: type,identity: IIdentity)

  __new__(cls: type,principal: IPrincipal)

  __new__(cls: type,reader: BinaryReader)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Claims=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Claims(self: ClaimsPrincipal) -> IEnumerable[Claim]



"""

 CustomSerializationData=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Identities=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Identities(self: ClaimsPrincipal) -> IEnumerable[ClaimsIdentity]



"""

 Identity=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Identity(self: ClaimsPrincipal) -> IIdentity



"""


 ClaimsPrincipalSelector=None
 Current=None


class ClaimTypes(object):
 # no doc
 Actor='http://schemas.xmlsoap.org/ws/2009/09/identity/claims/actor'
 Anonymous='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/anonymous'
 Authentication='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/authentication'
 AuthenticationInstant='http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationinstant'
 AuthenticationMethod='http://schemas.microsoft.com/ws/2008/06/identity/claims/authenticationmethod'
 AuthorizationDecision='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/authorizationdecision'
 CookiePath='http://schemas.microsoft.com/ws/2008/06/identity/claims/cookiepath'
 Country='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/country'
 DateOfBirth='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/dateofbirth'
 DenyOnlyPrimaryGroupSid='http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarygroupsid'
 DenyOnlyPrimarySid='http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlyprimarysid'
 DenyOnlySid='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/denyonlysid'
 DenyOnlyWindowsDeviceGroup='http://schemas.microsoft.com/ws/2008/06/identity/claims/denyonlywindowsdevicegroup'
 Dns='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/dns'
 Dsa='http://schemas.microsoft.com/ws/2008/06/identity/claims/dsa'
 Email='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress'
 Expiration='http://schemas.microsoft.com/ws/2008/06/identity/claims/expiration'
 Expired='http://schemas.microsoft.com/ws/2008/06/identity/claims/expired'
 Gender='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/gender'
 GivenName='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/givenname'
 GroupSid='http://schemas.microsoft.com/ws/2008/06/identity/claims/groupsid'
 Hash='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/hash'
 HomePhone='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/homephone'
 IsPersistent='http://schemas.microsoft.com/ws/2008/06/identity/claims/ispersistent'
 Locality='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/locality'
 MobilePhone='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/mobilephone'
 Name='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/name'
 NameIdentifier='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/nameidentifier'
 OtherPhone='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/otherphone'
 PostalCode='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/postalcode'
 PrimaryGroupSid='http://schemas.microsoft.com/ws/2008/06/identity/claims/primarygroupsid'
 PrimarySid='http://schemas.microsoft.com/ws/2008/06/identity/claims/primarysid'
 Role='http://schemas.microsoft.com/ws/2008/06/identity/claims/role'
 Rsa='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/rsa'
 SerialNumber='http://schemas.microsoft.com/ws/2008/06/identity/claims/serialnumber'
 Sid='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/sid'
 Spn='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/spn'
 StateOrProvince='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/stateorprovince'
 StreetAddress='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/streetaddress'
 Surname='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/surname'
 System='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/system'
 Thumbprint='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/thumbprint'
 Upn='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/upn'
 Uri='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/uri'
 UserData='http://schemas.microsoft.com/ws/2008/06/identity/claims/userdata'
 Version='http://schemas.microsoft.com/ws/2008/06/identity/claims/version'
 Webpage='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/webpage'
 WindowsAccountName='http://schemas.microsoft.com/ws/2008/06/identity/claims/windowsaccountname'
 WindowsDeviceClaim='http://schemas.microsoft.com/ws/2008/06/identity/claims/windowsdeviceclaim'
 WindowsDeviceGroup='http://schemas.microsoft.com/ws/2008/06/identity/claims/windowsdevicegroup'
 WindowsFqbnVersion='http://schemas.microsoft.com/ws/2008/06/identity/claims/windowsfqbnversion'
 WindowsSubAuthority='http://schemas.microsoft.com/ws/2008/06/identity/claims/windowssubauthority'
 WindowsUserClaim='http://schemas.microsoft.com/ws/2008/06/identity/claims/windowsuserclaim'
 X500DistinguishedName='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/x500distinguishedname'
 __all__=[
  'Actor',
  'Anonymous',
  'Authentication',
  'AuthenticationInstant',
  'AuthenticationMethod',
  'AuthorizationDecision',
  'CookiePath',
  'Country',
  'DateOfBirth',
  'DenyOnlyPrimaryGroupSid',
  'DenyOnlyPrimarySid',
  'DenyOnlySid',
  'DenyOnlyWindowsDeviceGroup',
  'Dns',
  'Dsa',
  'Email',
  'Expiration',
  'Expired',
  'Gender',
  'GivenName',
  'GroupSid',
  'Hash',
  'HomePhone',
  'IsPersistent',
  'Locality',
  'MobilePhone',
  'Name',
  'NameIdentifier',
  'OtherPhone',
  'PostalCode',
  'PrimaryGroupSid',
  'PrimarySid',
  'Role',
  'Rsa',
  'SerialNumber',
  'Sid',
  'Spn',
  'StateOrProvince',
  'StreetAddress',
  'Surname',
  'System',
  'Thumbprint',
  'Upn',
  'Uri',
  'UserData',
  'Version',
  'Webpage',
  'WindowsAccountName',
  'WindowsDeviceClaim',
  'WindowsDeviceGroup',
  'WindowsFqbnVersion',
  'WindowsSubAuthority',
  'WindowsUserClaim',
  'X500DistinguishedName',
 ]


class ClaimValueTypes(object):
 # no doc
 Base64Binary='http://www.w3.org/2001/XMLSchema#base64Binary'
 Base64Octet='http://www.w3.org/2001/XMLSchema#base64Octet'
 Boolean='http://www.w3.org/2001/XMLSchema#boolean'
 Date='http://www.w3.org/2001/XMLSchema#date'
 DateTime='http://www.w3.org/2001/XMLSchema#dateTime'
 DaytimeDuration='http://www.w3.org/TR/2002/WD-xquery-operators-20020816#dayTimeDuration'
 DnsName='http://schemas.xmlsoap.org/claims/dns'
 Double='http://www.w3.org/2001/XMLSchema#double'
 DsaKeyValue='http://www.w3.org/2000/09/xmldsig#DSAKeyValue'
 Email='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress'
 Fqbn='http://www.w3.org/2001/XMLSchema#fqbn'
 HexBinary='http://www.w3.org/2001/XMLSchema#hexBinary'
 Integer='http://www.w3.org/2001/XMLSchema#integer'
 Integer32='http://www.w3.org/2001/XMLSchema#integer32'
 Integer64='http://www.w3.org/2001/XMLSchema#integer64'
 KeyInfo='http://www.w3.org/2000/09/xmldsig#KeyInfo'
 Rfc822Name='urn:oasis:names:tc:xacml:1.0:data-type:rfc822Name'
 Rsa='http://schemas.xmlsoap.org/ws/2005/05/identity/claims/rsa'
 RsaKeyValue='http://www.w3.org/2000/09/xmldsig#RSAKeyValue'
 Sid='http://www.w3.org/2001/XMLSchema#sid'
 String='http://www.w3.org/2001/XMLSchema#string'
 Time='http://www.w3.org/2001/XMLSchema#time'
 UInteger32='http://www.w3.org/2001/XMLSchema#uinteger32'
 UInteger64='http://www.w3.org/2001/XMLSchema#uinteger64'
 UpnName='http://schemas.xmlsoap.org/claims/UPN'
 X500Name='urn:oasis:names:tc:xacml:1.0:data-type:x500Name'
 YearMonthDuration='http://www.w3.org/TR/2002/WD-xquery-operators-20020816#yearMonthDuration'
 __all__=[
  'Base64Binary',
  'Base64Octet',
  'Boolean',
  'Date',
  'DateTime',
  'DaytimeDuration',
  'DnsName',
  'Double',
  'DsaKeyValue',
  'Email',
  'Fqbn',
  'HexBinary',
  'Integer',
  'Integer32',
  'Integer64',
  'KeyInfo',
  'Rfc822Name',
  'Rsa',
  'RsaKeyValue',
  'Sid',
  'String',
  'Time',
  'UInteger32',
  'UInteger64',
  'UpnName',
  'X500Name',
  'YearMonthDuration',
 ]


class DynamicRoleClaimProvider(object):
 # no doc
 @staticmethod
 def AddDynamicRoleClaims(claimsIdentity,claims):
  """ AddDynamicRoleClaims(claimsIdentity: ClaimsIdentity,claims: IEnumerable[Claim]) """
  pass
 __all__=[
  'AddDynamicRoleClaims',
 ]





# encoding: utf-8
# module System
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# functions

def Action(p_object,method): # real signature unknown; restored from __doc__
 """
 Encapsulates a method that has no parameters and does not return a value.

 

 Action(object: object,method: IntPtr)
 """
 pass
def EventHandler(p_object,method): # real signature unknown; restored from __doc__
 """
 Represents the method that will handle an event that has no event data.

 

 EventHandler(object: object,method: IntPtr)
 """
 pass
def Func(*args,**kwargs): # real signature unknown
 """
 A TypeCollision is used when we have a collision between

    two types with the same name.  Currently this is only possible w/ generic

    methods that should logically have arity as a portion of their name. For eg:

      System.EventHandler and System.EventHandler[T]

      System.Nullable and System.Nullable[T]

      System.IComparable and System.IComparable[T]

    

    The TypeCollision provides an indexer but also is a real type.  When used

    as a real type it is the non-generic form of the type.

    

    The indexer allows the user to disambiguate between the generic and

    non-generic versions.  Therefore users must always provide additional

    information to get the generic version.
 """
 pass
def IComparable(*args,**kwargs): # real signature unknown
 """ Defines a generalized type-specific comparison method that a value type or class implements to order or sort its instances. """
 pass
def Nullable(*args,**kwargs): # real signature unknown
 """ Supports a value type that can be assigned null like a reference type. This class cannot be inherited. """
 pass
def Tuple(*args,**kwargs): # real signature unknown
 """ Provides static methods for creating tuple objects. """
 pass
def ValueTuple(*args,**kwargs): # real signature unknown
 """  """
 pass
def WeakReference(target): # real signature unknown; restored from __doc__
 """
 Represents a weak reference,which references an object while still allowing that object to be reclaimed by garbage collection.

 

 WeakReference(target: object)

 WeakReference(target: object,trackResurrection: bool)
 """
 pass
# classes
from __init___parts.Object import Object
from __init___parts.Exception import Exception
from __init___parts.SystemException import SystemException
from __init___parts.AccessViolationException import AccessViolationException
from __init___parts.IDisposable import IDisposable
from __init___parts.ActivationContext import ActivationContext
from __init___parts.Activator import Activator
from __init___parts.AggregateException import AggregateException
from __init___parts.AppContext import AppContext
from __init___parts.MarshalByRefObject import MarshalByRefObject
from __init___parts._AppDomain import _AppDomain
from __init___parts.AppDomain import AppDomain
from __init___parts.Delegate import Delegate
from __init___parts.MulticastDelegate import MulticastDelegate
from __init___parts.AppDomainInitializer import AppDomainInitializer
from __init___parts.AppDomainManager import AppDomainManager
from __init___parts.IConvertible import IConvertible
from __init___parts.IFormattable import IFormattable
from __init___parts.Enum import Enum
from __init___parts.AppDomainManagerInitializationOptions import AppDomainManagerInitializationOptions
from __init___parts.AppDomainSetup import AppDomainSetup
from __init___parts.AppDomainUnloadedException import AppDomainUnloadedException
from __init___parts.ApplicationException import ApplicationException
from __init___parts.ApplicationId import ApplicationId
from __init___parts.ApplicationIdentity import ApplicationIdentity
from __init___parts.ArgIterator import ArgIterator
from __init___parts.ArgumentException import ArgumentException
from __init___parts.ArgumentNullException import ArgumentNullException
from __init___parts.ArgumentOutOfRangeException import ArgumentOutOfRangeException
from __init___parts.ArithmeticException import ArithmeticException
from __init___parts.ICloneable import ICloneable
from __init___parts.Array import Array
from __init___parts.ArraySegment import ArraySegment
from __init___parts.ArrayTypeMismatchException import ArrayTypeMismatchException
from __init___parts.EventArgs import EventArgs
from __init___parts.AssemblyLoadEventArgs import AssemblyLoadEventArgs
from __init___parts.AssemblyLoadEventHandler import AssemblyLoadEventHandler
from __init___parts.AsyncCallback import AsyncCallback
from __init___parts.Attribute import Attribute
from __init___parts.AttributeTargets import AttributeTargets
from __init___parts.AttributeUsageAttribute import AttributeUsageAttribute
from __init___parts.BadImageFormatException import BadImageFormatException
from __init___parts.Base64FormattingOptions import Base64FormattingOptions
from __init___parts.BitConverter import BitConverter
from __init___parts.Int32 import Int32
from __init___parts.Boolean import Boolean
from __init___parts.Buffer import Buffer
from __init___parts.Byte import Byte
from __init___parts.CannotUnloadAppDomainException import CannotUnloadAppDomainException
from __init___parts.Char import Char
from __init___parts.CharEnumerator import CharEnumerator
from __init___parts.CLSCompliantAttribute import CLSCompliantAttribute
from __init___parts.Comparison import Comparison
from __init___parts.Console import Console
from __init___parts.ConsoleCancelEventArgs import ConsoleCancelEventArgs
from __init___parts.ConsoleCancelEventHandler import ConsoleCancelEventHandler
from __init___parts.ConsoleColor import ConsoleColor
from __init___parts.ConsoleKey import ConsoleKey
from __init___parts.ConsoleKeyInfo import ConsoleKeyInfo
from __init___parts.ConsoleModifiers import ConsoleModifiers
from __init___parts.ConsoleSpecialKey import ConsoleSpecialKey
from __init___parts.ContextBoundObject import ContextBoundObject
from __init___parts.ContextMarshalException import ContextMarshalException
from __init___parts.ContextStaticAttribute import ContextStaticAttribute
from __init___parts.Convert import Convert
from __init___parts.Converter import Converter
from __init___parts.CrossAppDomainDelegate import CrossAppDomainDelegate
from __init___parts.DataMisalignedException import DataMisalignedException
from __init___parts.DateTime import DateTime
from __init___parts.DateTimeKind import DateTimeKind
from __init___parts.DateTimeOffset import DateTimeOffset
from __init___parts.DayOfWeek import DayOfWeek
from __init___parts.DBNull import DBNull
from __init___parts.Decimal import Decimal
from __init___parts.DivideByZeroException import DivideByZeroException
from __init___parts.TypeLoadException import TypeLoadException
from __init___parts.DllNotFoundException import DllNotFoundException
from __init___parts.Double import Double
from __init___parts.DuplicateWaitObjectException import DuplicateWaitObjectException
from __init___parts.EntryPointNotFoundException import EntryPointNotFoundException
from __init___parts.Environment import Environment
from __init___parts.EnvironmentVariableTarget import EnvironmentVariableTarget
from __init___parts.ExecutionEngineException import ExecutionEngineException
from __init___parts.MemberAccessException import MemberAccessException
from __init___parts.FieldAccessException import FieldAccessException
from __init___parts.UriParser import UriParser
from __init___parts.FileStyleUriParser import FileStyleUriParser
from __init___parts.FlagsAttribute import FlagsAttribute
from __init___parts.FormatException import FormatException
from __init___parts.FormattableString import FormattableString
from __init___parts.FtpStyleUriParser import FtpStyleUriParser
from __init___parts.GC import GC
from __init___parts.GCCollectionMode import GCCollectionMode
from __init___parts.GCNotificationStatus import GCNotificationStatus
from __init___parts.GenericUriParser import GenericUriParser
from __init___parts.GenericUriParserOptions import GenericUriParserOptions
from __init___parts.GopherStyleUriParser import GopherStyleUriParser
from __init___parts.Guid import Guid
from __init___parts.HttpStyleUriParser import HttpStyleUriParser
from __init___parts.IAppDomainSetup import IAppDomainSetup
from __init___parts.IAsyncResult import IAsyncResult
from __init___parts.ICustomFormatter import ICustomFormatter
from __init___parts.IEquatable import IEquatable
from __init___parts.IFormatProvider import IFormatProvider
from __init___parts.IndexOutOfRangeException import IndexOutOfRangeException
from __init___parts.InsufficientExecutionStackException import InsufficientExecutionStackException
from __init___parts.OutOfMemoryException import OutOfMemoryException
from __init___parts.InsufficientMemoryException import InsufficientMemoryException
from __init___parts.Int16 import Int16
from __init___parts.Int64 import Int64
from __init___parts.IntPtr import IntPtr
from __init___parts.InvalidCastException import InvalidCastException
from __init___parts.InvalidOperationException import InvalidOperationException
from __init___parts.InvalidProgramException import InvalidProgramException
from __init___parts.InvalidTimeZoneException import InvalidTimeZoneException
from __init___parts.IObservable import IObservable
from __init___parts.IObserver import IObserver
from __init___parts.IProgress import IProgress
from __init___parts.IServiceProvider import IServiceProvider
from __init___parts.Lazy import Lazy
from __init___parts.LdapStyleUriParser import LdapStyleUriParser
from __init___parts.LoaderOptimization import LoaderOptimization
from __init___parts.LoaderOptimizationAttribute import LoaderOptimizationAttribute
from __init___parts.LocalDataStoreSlot import LocalDataStoreSlot
from __init___parts.Math import Math
from __init___parts.MethodAccessException import MethodAccessException
from __init___parts.MidpointRounding import MidpointRounding
from __init___parts.MissingMemberException import MissingMemberException
from __init___parts.MissingFieldException import MissingFieldException
from __init___parts.MissingMethodException import MissingMethodException
from __init___parts.ModuleHandle import ModuleHandle
from __init___parts.MTAThreadAttribute import MTAThreadAttribute
from __init___parts.MulticastNotSupportedException import MulticastNotSupportedException
from __init___parts.NetPipeStyleUriParser import NetPipeStyleUriParser
from __init___parts.NetTcpStyleUriParser import NetTcpStyleUriParser
from __init___parts.NewsStyleUriParser import NewsStyleUriParser
from __init___parts.NonSerializedAttribute import NonSerializedAttribute
from __init___parts.NotFiniteNumberException import NotFiniteNumberException
from __init___parts.NotImplementedException import NotImplementedException
from __init___parts.NotSupportedException import NotSupportedException
from __init___parts.NullReferenceException import NullReferenceException
from __init___parts.ObjectDisposedException import ObjectDisposedException
from __init___parts.ObsoleteAttribute import ObsoleteAttribute
from __init___parts.OperatingSystem import OperatingSystem
from __init___parts.OperationCanceledException import OperationCanceledException
from __init___parts.OverflowException import OverflowException
from __init___parts.ParamArrayAttribute import ParamArrayAttribute
from __init___parts.PlatformID import PlatformID
from __init___parts.PlatformNotSupportedException import PlatformNotSupportedException
from __init___parts.Predicate import Predicate
from __init___parts.Progress import Progress
from __init___parts.Random import Random
from __init___parts.RankException import RankException
from __init___parts.ResolveEventArgs import ResolveEventArgs
from __init___parts.ResolveEventHandler import ResolveEventHandler
from __init___parts.RuntimeArgumentHandle import RuntimeArgumentHandle
from __init___parts.RuntimeFieldHandle import RuntimeFieldHandle
from __init___parts.RuntimeMethodHandle import RuntimeMethodHandle
from __init___parts.RuntimeTypeHandle import RuntimeTypeHandle
from __init___parts.SByte import SByte
from __init___parts.SerializableAttribute import SerializableAttribute
from __init___parts.Single import Single
from __init___parts.StackOverflowException import StackOverflowException
from __init___parts.STAThreadAttribute import STAThreadAttribute
from __init___parts.String import String
from __init___parts.StringComparer import StringComparer
from __init___parts.StringComparison import StringComparison
from __init___parts.StringSplitOptions import StringSplitOptions
from __init___parts.ThreadStaticAttribute import ThreadStaticAttribute
from __init___parts.TimeoutException import TimeoutException
from __init___parts.TimeSpan import TimeSpan
from __init___parts.TimeZone import TimeZone
from __init___parts.TimeZoneInfo import TimeZoneInfo
from __init___parts.TimeZoneNotFoundException import TimeZoneNotFoundException
from __init___parts.TupleExtensions import TupleExtensions
from __init___parts.Type import Type
from __init___parts.TypeAccessException import TypeAccessException
from __init___parts.TypeCode import TypeCode
from __init___parts.TypedReference import TypedReference
from __init___parts.TypeInitializationException import TypeInitializationException
from __init___parts.TypeUnloadedException import TypeUnloadedException
from __init___parts.UInt16 import UInt16
from __init___parts.UInt32 import UInt32
from __init___parts.UInt64 import UInt64
from __init___parts.UIntPtr import UIntPtr
from __init___parts.UnauthorizedAccessException import UnauthorizedAccessException
from __init___parts.UnhandledExceptionEventArgs import UnhandledExceptionEventArgs
from __init___parts.UnhandledExceptionEventHandler import UnhandledExceptionEventHandler
from __init___parts.Uri import Uri
from __init___parts.UriBuilder import UriBuilder
from __init___parts.UriComponents import UriComponents
from __init___parts.UriFormat import UriFormat
from __init___parts.UriFormatException import UriFormatException
from __init___parts.UriHostNameType import UriHostNameType
from __init___parts.UriIdnScope import UriIdnScope
from __init___parts.UriKind import UriKind
from __init___parts.UriPartial import UriPartial
from __init___parts.UriTypeConverter import UriTypeConverter
from __init___parts.ValueType import ValueType
from __init___parts.Version import Version
from __init___parts.Void import Void



class CookieException(FormatException,ISerializable,_Exception):
 """
 The exception that is thrown when an error is made adding a System.Net.Cookie to a System.Net.CookieContainer.

 

 CookieException()
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,serializationInfo,streamingContext):
  """
  GetObjectData(self: CookieException,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo instance with the data needed to 

    serialize the System.Net.CookieException.

  

  

   serializationInfo: The object that holds the serialized object data. The 

    System.Runtime.Serialization.SerializationInfo to populate with data.

  

   streamingContext: The contextual information about the source or destination. A 

    System.Runtime.Serialization.StreamingContext that specifies the destination for this 

    serialization.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self):
  """
  __new__(cls: type)

  __new__(cls: type,serializationInfo: SerializationInfo,streamingContext: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass



class CommonAcl(GenericAcl,ICollection,IEnumerable):
 """ Represents an access control list (ACL) and is the base class for the System.Security.AccessControl.DiscretionaryAcl and System.Security.AccessControl.SystemAcl classes. """
 def GetBinaryForm(self,binaryForm,offset):
  """
  GetBinaryForm(self: CommonAcl,binaryForm: Array[Byte],offset: int)

   Marshals the contents of the System.Security.AccessControl.CommonAcl object into the specified 

    byte array beginning at the specified offset.

  

  

   binaryForm: The byte array into which the contents of the System.Security.AccessControl.CommonAcl is 

    marshaled.

  

   offset: The offset at which to start marshaling.
  """
  pass
 def Purge(self,sid):
  """
  Purge(self: CommonAcl,sid: SecurityIdentifier)

   Removes all access control entries (ACEs) contained by this 

    System.Security.AccessControl.CommonAcl object that are associated with the specified 

    System.Security.Principal.SecurityIdentifier object.

  

  

   sid: The System.Security.Principal.SecurityIdentifier object to check for.
  """
  pass
 def RemoveInheritedAces(self):
  """
  RemoveInheritedAces(self: CommonAcl)

   Removes all inherited access control entries (ACEs) from this 

    System.Security.AccessControl.CommonAcl object.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 BinaryLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length,in bytes,of the binary representation of the current System.Security.AccessControl.CommonAcl object. This length should be used before marshaling the access control list (ACL) into a binary array by using the System.Security.AccessControl.CommonAcl.GetBinaryForm method.



Get: BinaryLength(self: CommonAcl) -> int



"""

 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of access control entries (ACEs) in the current System.Security.AccessControl.CommonAcl object.



Get: Count(self: CommonAcl) -> int



"""

 IsCanonical=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a Boolean value that specifies whether the access control entries (ACEs) in the current System.Security.AccessControl.CommonAcl object are in canonical order.



Get: IsCanonical(self: CommonAcl) -> bool



"""

 IsContainer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Sets whether the System.Security.AccessControl.CommonAcl object is a container.



Get: IsContainer(self: CommonAcl) -> bool



"""

 IsDS=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Sets whether the current System.Security.AccessControl.CommonAcl object is a directory object access control list (ACL).



Get: IsDS(self: CommonAcl) -> bool



"""

 Revision=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the revision level of the System.Security.AccessControl.CommonAcl.



Get: Revision(self: CommonAcl) -> Byte



"""





class GeneratorPosition(object):
 """
 System.Windows.Controls.Primitives.GeneratorPosition is used to describe the position of an item that is managed by System.Windows.Controls.ItemContainerGenerator.

 

 GeneratorPosition(index: int,offset: int)
 """
 def Equals(self,o):
  """
  Equals(self: GeneratorPosition,o: object) -> bool

  

   Compares the specified instance and the current instance of 

    System.Windows.Controls.Primitives.GeneratorPosition for value equality.

  

  

   o: The System.Windows.Controls.Primitives.GeneratorPosition instance to compare.

   Returns: true if o and this instance of System.Windows.Controls.Primitives.GeneratorPosition have the 

    same values.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: GeneratorPosition) -> int

  

   Returns the hash code for this System.Windows.Controls.Primitives.GeneratorPosition.

   Returns: The hash code for this System.Windows.Controls.Primitives.GeneratorPosition.
  """
  pass
 def ToString(self):
  """
  ToString(self: GeneratorPosition) -> str

  

   Returns a string representation of this instance of 

    System.Windows.Controls.Primitives.GeneratorPosition.

  

   Returns: A string representation of this instance of System.Windows.Controls.Primitives.GeneratorPosition
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,index,offset):
  """
  __new__(cls: type,index: int,offset: int)

  __new__[GeneratorPosition]() -> GeneratorPosition
  """
  pass
 def __ne__(self,*args):
  pass
 Index=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Int32 index that is relative to the generated (realized) items.



Get: Index(self: GeneratorPosition) -> int



Set: Index(self: GeneratorPosition)=value

"""

 Offset=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Int32 offset that is relative to the ungenerated (unrealized) items near the indexed item.



Get: Offset(self: GeneratorPosition) -> int



Set: Offset(self: GeneratorPosition)=value

"""





from typing import Tuple, Set, Iterable, List


class FunctionId:
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...
    @property
    def File(self) -> str: ...
    @property
    def Line(self) -> int: ...
    @property
    def Function(self) -> str: ...


class ApplicationException:
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...
    @property
    def FunctionId(self) -> FunctionId: ...


class ArgumentException(ApplicationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...
    @property
    def Message(self) -> str: ...
    @property
    def ParamName(self) -> str: ...


class ArgumentOutOfRangeException(ArgumentException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class ArgumentNullException(ArgumentException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class InvalidPathArgumentException(ArgumentException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class FileArgumentNotFoundException(ArgumentException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class FileArgumentAlreadyExistsException(ArgumentException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class ArgumentsInconsistentException(ArgumentException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class InvalidOperationException(ApplicationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class InvalidObjectException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class ModificationOutsideTransactionException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class ModificationForbiddenException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class ObjectAccessException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class InapplicableDataException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class FamilyContextException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class DisabledDisciplineException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class InsufficientResourcesException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class IOException(ApplicationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class FileNotFoundException(IOException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class DirectoryNotFoundException(IOException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class FileAccessException(IOException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class InvalidDataStreamException(IOException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class InternalException(ApplicationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class ExternalApplicationException(ApplicationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class RegenerationFailedException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class AutoJoinFailedException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class ForbiddenForDynamicUpdateException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class OptionalFunctionalityNotAvailableException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class OperationCanceledException(ApplicationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class CorruptModelException(ApplicationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class RevitServerException(ApplicationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class RevitServerCommunicationException(RevitServerException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class RevitServerInternalException(RevitServerException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class RevitServerUnauthorizedException(RevitServerException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class RevitServerUnauthenticatedUserException(RevitServerException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class RevitServerCollaborationNotAvailableException(RevitServerException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class CentralModelException(ApplicationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class CentralFileCommunicationException(CentralModelException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class CentralModelAccessDeniedException(CentralModelException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class CentralModelContentionException(CentralModelException):
    @property
    def CurrentUser(self) -> str: ...
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class OutdatedDirectlyOpenedCentralException(CentralModelException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class CentralModelAlreadyExistsException(CentralModelException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class CentralModelVersionArchivedException(CentralModelException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class CheckoutElementsRequestTooLargeException(CentralModelException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class WrongUserException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class TransmittedModelException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class NotTransmittedModelException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class CannotOpenBothCentralAndLocalException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class TransientElementCreationException(InvalidOperationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...


class BackgroundTaskCancelledException(ApplicationException):
    def GetObjectData(self, info: SerializationInfo, context: StreamingContext) -> None: ...



"""Selection utilities."""
from pyrevit.revit.db import query


def select_mirrored(elements):
    """Select only mirrored elements from the given elements."""
    return [x for x in elements
            if hasattr(x, "Mirrored") and x.Mirrored]
